package validator

var iso3166_1_alpha2 = map[string]bool{
	// see: https://www.iso.org/iso-3166-country-codes.html
	"AF": true, "AX": true, "AL": true, "DZ": true, "AS": true,
	"AD": true, "AO": true, "AI": true, "AQ": true, "AG": true,
	"AR": true, "AM": true, "AW": true, "AU": true, "AT": true,
	"AZ": true, "BS": true, "BH": true, "BD": true, "BB": true,
	"BY": true, "BE": true, "BZ": true, "BJ": true, "BM": true,
	"BT": true, "BO": true, "BQ": true, "BA": true, "BW": true,
	"BV": true, "BR": true, "IO": true, "BN": true, "BG": true,
	"BF": true, "BI": true, "KH": true, "CM": true, "CA": true,
	"CV": true, "KY": true, "CF": true, "TD": true, "CL": true,
	"CN": true, "CX": true, "CC": true, "CO": true, "KM": true,
	"CG": true, "CD": true, "CK": true, "CR": true, "CI": true,
	"HR": true, "CU": true, "CW": true, "CY": true, "CZ": true,
	"DK": true, "DJ": true, "DM": true, "DO": true, "EC": true,
	"EG": true, "SV": true, "GQ": true, "ER": true, "EE": true,
	"ET": true, "FK": true, "FO": true, "FJ": true, "FI": true,
	"FR": true, "GF": true, "PF": true, "TF": true, "GA": true,
	"GM": true, "GE": true, "DE": true, "GH": true, "GI": true,
	"GR": true, "GL": true, "GD": true, "GP": true, "GU": true,
	"GT": true, "GG": true, "GN": true, "GW": true, "GY": true,
	"HT": true, "HM": true, "VA": true, "HN": true, "HK": true,
	"HU": true, "IS": true, "IN": true, "ID": true, "IR": true,
	"IQ": true, "IE": true, "IM": true, "IL": true, "IT": true,
	"JM": true, "JP": true, "JE": true, "JO": true, "KZ": true,
	"KE": true, "KI": true, "KP": true, "KR": true, "KW": true,
	"KG": true, "LA": true, "LV": true, "LB": true, "LS": true,
	"LR": true, "LY": true, "LI": true, "LT": true, "LU": true,
	"MO": true, "MK": true, "MG": true, "MW": true, "MY": true,
	"MV": true, "ML": true, "MT": true, "MH": true, "MQ": true,
	"MR": true, "MU": true, "YT": true, "MX": true, "FM": true,
	"MD": true, "MC": true, "MN": true, "ME": true, "MS": true,
	"MA": true, "MZ": true, "MM": true, "NA": true, "NR": true,
	"NP": true, "NL": true, "NC": true, "NZ": true, "NI": true,
	"NE": true, "NG": true, "NU": true, "NF": true, "MP": true,
	"NO": true, "OM": true, "PK": true, "PW": true, "PS": true,
	"PA": true, "PG": true, "PY": true, "PE": true, "PH": true,
	"PN": true, "PL": true, "PT": true, "PR": true, "QA": true,
	"RE": true, "RO": true, "RU": true, "RW": true, "BL": true,
	"SH": true, "KN": true, "LC": true, "MF": true, "PM": true,
	"VC": true, "WS": true, "SM": true, "ST": true, "SA": true,
	"SN": true, "RS": true, "SC": true, "SL": true, "SG": true,
	"SX": true, "SK": true, "SI": true, "SB": true, "SO": true,
	"ZA": true, "GS": true, "SS": true, "ES": true, "LK": true,
	"SD": true, "SR": true, "SJ": true, "SZ": true, "SE": true,
	"CH": true, "SY": true, "TW": true, "TJ": true, "TZ": true,
	"TH": true, "TL": true, "TG": true, "TK": true, "TO": true,
	"TT": true, "TN": true, "TR": true, "TM": true, "TC": true,
	"TV": true, "UG": true, "UA": true, "AE": true, "GB": true,
	"US": true, "UM": true, "UY": true, "UZ": true, "VU": true,
	"VE": true, "VN": true, "VG": true, "VI": true, "WF": true,
	"EH": true, "YE": true, "ZM": true, "ZW": true, "XK": true,
}

var iso3166_1_alpha3 = map[string]bool{
	// see: https://www.iso.org/iso-3166-country-codes.html
	"AFG": true, "ALB": true, "DZA": true, "ASM": true, "AND": true,
	"AGO": true, "AIA": true, "ATA": true, "ATG": true, "ARG": true,
	"ARM": true, "ABW": true, "AUS": true, "AUT": true, "AZE": true,
	"BHS": true, "BHR": true, "BGD": true, "BRB": true, "BLR": true,
	"BEL": true, "BLZ": true, "BEN": true, "BMU": true, "BTN": true,
	"BOL": true, "BES": true, "BIH": true, "BWA": true, "BVT": true,
	"BRA": true, "IOT": true, "BRN": true, "BGR": true, "BFA": true,
	"BDI": true, "CPV": true, "KHM": true, "CMR": true, "CAN": true,
	"CYM": true, "CAF": true, "TCD": true, "CHL": true, "CHN": true,
	"CXR": true, "CCK": true, "COL": true, "COM": true, "COD": true,
	"COG": true, "COK": true, "CRI": true, "HRV": true, "CUB": true,
	"CUW": true, "CYP": true, "CZE": true, "CIV": true, "DNK": true,
	"DJI": true, "DMA": true, "DOM": true, "ECU": true, "EGY": true,
	"SLV": true, "GNQ": true, "ERI": true, "EST": true, "SWZ": true,
	"ETH": true, "FLK": true, "FRO": true, "FJI": true, "FIN": true,
	"FRA": true, "GUF": true, "PYF": true, "ATF": true, "GAB": true,
	"GMB": true, "GEO": true, "DEU": true, "GHA": true, "GIB": true,
	"GRC": true, "GRL": true, "GRD": true, "GLP": true, "GUM": true,
	"GTM": true, "GGY": true, "GIN": true, "GNB": true, "GUY": true,
	"HTI": true, "HMD": true, "VAT": true, "HND": true, "HKG": true,
	"HUN": true, "ISL": true, "IND": true, "IDN": true, "IRN": true,
	"IRQ": true, "IRL": true, "IMN": true, "ISR": true, "ITA": true,
	"JAM": true, "JPN": true, "JEY": true, "JOR": true, "KAZ": true,
	"KEN": true, "KIR": true, "PRK": true, "KOR": true, "KWT": true,
	"KGZ": true, "LAO": true, "LVA": true, "LBN": true, "LSO": true,
	"LBR": true, "LBY": true, "LIE": true, "LTU": true, "LUX": true,
	"MAC": true, "MDG": true, "MWI": true, "MYS": true, "MDV": true,
	"MLI": true, "MLT": true, "MHL": true, "MTQ": true, "MRT": true,
	"MUS": true, "MYT": true, "MEX": true, "FSM": true, "MDA": true,
	"MCO": true, "MNG": true, "MNE": true, "MSR": true, "MAR": true,
	"MOZ": true, "MMR": true, "NAM": true, "NRU": true, "NPL": true,
	"NLD": true, "NCL": true, "NZL": true, "NIC": true, "NER": true,
	"NGA": true, "NIU": true, "NFK": true, "MKD": true, "MNP": true,
	"NOR": true, "OMN": true, "PAK": true, "PLW": true, "PSE": true,
	"PAN": true, "PNG": true, "PRY": true, "PER": true, "PHL": true,
	"PCN": true, "POL": true, "PRT": true, "PRI": true, "QAT": true,
	"ROU": true, "RUS": true, "RWA": true, "REU": true, "BLM": true,
	"SHN": true, "KNA": true, "LCA": true, "MAF": true, "SPM": true,
	"VCT": true, "WSM": true, "SMR": true, "STP": true, "SAU": true,
	"SEN": true, "SRB": true, "SYC": true, "SLE": true, "SGP": true,
	"SXM": true, "SVK": true, "SVN": true, "SLB": true, "SOM": true,
	"ZAF": true, "SGS": true, "SSD": true, "ESP": true, "LKA": true,
	"SDN": true, "SUR": true, "SJM": true, "SWE": true, "CHE": true,
	"SYR": true, "TWN": true, "TJK": true, "TZA": true, "THA": true,
	"TLS": true, "TGO": true, "TKL": true, "TON": true, "TTO": true,
	"TUN": true, "TUR": true, "TKM": true, "TCA": true, "TUV": true,
	"UGA": true, "UKR": true, "ARE": true, "GBR": true, "UMI": true,
	"USA": true, "URY": true, "UZB": true, "VUT": true, "VEN": true,
	"VNM": true, "VGB": true, "VIR": true, "WLF": true, "ESH": true,
	"YEM": true, "ZMB": true, "ZWE": true, "ALA": true, "UNK": true,
}
var iso3166_1_alpha_numeric = map[int]bool{
	// see: https://www.iso.org/iso-3166-country-codes.html
	4: true, 8: true, 12: true, 16: true, 20: true,
	24: true, 660: true, 10: true, 28: true, 32: true,
	51: true, 533: true, 36: true, 40: true, 31: true,
	44: true, 48: true, 50: true, 52: true, 112: true,
	56: true, 84: true, 204: true, 60: true, 64: true,
	68: true, 535: true, 70: true, 72: true, 74: true,
	76: true, 86: true, 96: true, 100: true, 854: true,
	108: true, 132: true, 116: true, 120: true, 124: true,
	136: true, 140: true, 148: true, 152: true, 156: true,
	162: true, 166: true, 170: true, 174: true, 180: true,
	178: true, 184: true, 188: true, 191: true, 192: true,
	531: true, 196: true, 203: true, 384: true, 208: true,
	262: true, 212: true, 214: true, 218: true, 818: true,
	222: true, 226: true, 232: true, 233: true, 748: true,
	231: true, 238: true, 234: true, 242: true, 246: true,
	250: true, 254: true, 258: true, 260: true, 266: true,
	270: true, 268: true, 276: true, 288: true, 292: true,
	300: true, 304: true, 308: true, 312: true, 316: true,
	320: true, 831: true, 324: true, 624: true, 328: true,
	332: true, 334: true, 336: true, 340: true, 344: true,
	348: true, 352: true, 356: true, 360: true, 364: true,
	368: true, 372: true, 833: true, 376: true, 380: true,
	388: true, 392: true, 832: true, 400: true, 398: true,
	404: true, 296: true, 408: true, 410: true, 414: true,
	417: true, 418: true, 428: true, 422: true, 426: true,
	430: true, 434: true, 438: true, 440: true, 442: true,
	446: true, 450: true, 454: true, 458: true, 462: true,
	466: true, 470: true, 584: true, 474: true, 478: true,
	480: true, 175: true, 484: true, 583: true, 498: true,
	492: true, 496: true, 499: true, 500: true, 504: true,
	508: true, 104: true, 516: true, 520: true, 524: true,
	528: true, 540: true, 554: true, 558: true, 562: true,
	566: true, 570: true, 574: true, 807: true, 580: true,
	578: true, 512: true, 586: true, 585: true, 275: true,
	591: true, 598: true, 600: true, 604: true, 608: true,
	612: true, 616: true, 620: true, 630: true, 634: true,
	642: true, 643: true, 646: true, 638: true, 652: true,
	654: true, 659: true, 662: true, 663: true, 666: true,
	670: true, 882: true, 674: true, 678: true, 682: true,
	686: true, 688: true, 690: true, 694: true, 702: true,
	534: true, 703: true, 705: true, 90: true, 706: true,
	710: true, 239: true, 728: true, 724: true, 144: true,
	729: true, 740: true, 744: true, 752: true, 756: true,
	760: true, 158: true, 762: true, 834: true, 764: true,
	626: true, 768: true, 772: true, 776: true, 780: true,
	788: true, 792: true, 795: true, 796: true, 798: true,
	800: true, 804: true, 784: true, 826: true, 581: true,
	840: true, 858: true, 860: true, 548: true, 862: true,
	704: true, 92: true, 850: true, 876: true, 732: true,
	887: true, 894: true, 716: true, 248: true, 153: true,
}

var iso3166_2 = map[string]bool{
	"AD-02": true, "AD-03": true, "AD-04": true, "AD-05": true, "AD-06": true,
	"AD-07": true, "AD-08": true, "AE-AJ": true, "AE-AZ": true, "AE-DU": true,
	"AE-FU": true, "AE-RK": true, "AE-SH": true, "AE-UQ": true, "AF-BAL": true,
	"AF-BAM": true, "AF-BDG": true, "AF-BDS": true, "AF-BGL": true, "AF-DAY": true,
	"AF-FRA": true, "AF-FYB": true, "AF-GHA": true, "AF-GHO": true, "AF-HEL": true,
	"AF-HER": true, "AF-JOW": true, "AF-KAB": true, "AF-KAN": true, "AF-KAP": true,
	"AF-KDZ": true, "AF-KHO": true, "AF-KNR": true, "AF-LAG": true, "AF-LOG": true,
	"AF-NAN": true, "AF-NIM": true, "AF-NUR": true, "AF-PAN": true, "AF-PAR": true,
	"AF-PIA": true, "AF-PKA": true, "AF-SAM": true, "AF-SAR": true, "AF-TAK": true,
	"AF-URU": true, "AF-WAR": true, "AF-ZAB": true, "AG-03": true, "AG-04": true,
	"AG-05": true, "AG-06": true, "AG-07": true, "AG-08": true, "AG-10": true,
	"AG-11": true, "AL-01": true, "AL-02": true, "AL-03": true, "AL-04": true,
	"AL-05": true, "AL-06": true, "AL-07": true, "AL-08": true, "AL-09": true,
	"AL-10": true, "AL-11": true, "AL-12": true, "AL-BR": true, "AL-BU": true,
	"AL-DI": true, "AL-DL": true, "AL-DR": true, "AL-DV": true, "AL-EL": true,
	"AL-ER": true, "AL-FR": true, "AL-GJ": true, "AL-GR": true, "AL-HA": true,
	"AL-KA": true, "AL-KB": true, "AL-KC": true, "AL-KO": true, "AL-KR": true,
	"AL-KU": true, "AL-LB": true, "AL-LE": true, "AL-LU": true, "AL-MK": true,
	"AL-MM": true, "AL-MR": true, "AL-MT": true, "AL-PG": true, "AL-PQ": true,
	"AL-PR": true, "AL-PU": true, "AL-SH": true, "AL-SK": true, "AL-SR": true,
	"AL-TE": true, "AL-TP": true, "AL-TR": true, "AL-VL": true, "AM-AG": true,
	"AM-AR": true, "AM-AV": true, "AM-ER": true, "AM-GR": true, "AM-KT": true,
	"AM-LO": true, "AM-SH": true, "AM-SU": true, "AM-TV": true, "AM-VD": true,
	"AO-BGO": true, "AO-BGU": true, "AO-BIE": true, "AO-CAB": true, "AO-CCU": true,
	"AO-CNN": true, "AO-CNO": true, "AO-CUS": true, "AO-HUA": true, "AO-HUI": true,
	"AO-LNO": true, "AO-LSU": true, "AO-LUA": true, "AO-MAL": true, "AO-MOX": true,
	"AO-NAM": true, "AO-UIG": true, "AO-ZAI": true, "AR-A": true, "AR-B": true,
	"AR-C": true, "AR-D": true, "AR-E": true, "AR-F": true, "AR-G": true, "AR-H": true,
	"AR-J": true, "AR-K": true, "AR-L": true, "AR-M": true, "AR-N": true,
	"AR-P": true, "AR-Q": true, "AR-R": true, "AR-S": true, "AR-T": true,
	"AR-U": true, "AR-V": true, "AR-W": true, "AR-X": true, "AR-Y": true,
	"AR-Z": true, "AT-1": true, "AT-2": true, "AT-3": true, "AT-4": true,
	"AT-5": true, "AT-6": true, "AT-7": true, "AT-8": true, "AT-9": true,
	"AU-ACT": true, "AU-NSW": true, "AU-NT": true, "AU-QLD": true, "AU-SA": true,
	"AU-TAS": true, "AU-VIC": true, "AU-WA": true, "AZ-ABS": true, "AZ-AGA": true,
	"AZ-AGC": true, "AZ-AGM": true, "AZ-AGS": true, "AZ-AGU": true, "AZ-AST": true,
	"AZ-BA": true, "AZ-BAB": true, "AZ-BAL": true, "AZ-BAR": true, "AZ-BEY": true,
	"AZ-BIL": true, "AZ-CAB": true, "AZ-CAL": true, "AZ-CUL": true, "AZ-DAS": true,
	"AZ-FUZ": true, "AZ-GA": true, "AZ-GAD": true, "AZ-GOR": true, "AZ-GOY": true,
	"AZ-GYG": true, "AZ-HAC": true, "AZ-IMI": true, "AZ-ISM": true, "AZ-KAL": true,
	"AZ-KAN": true, "AZ-KUR": true, "AZ-LA": true, "AZ-LAC": true, "AZ-LAN": true,
	"AZ-LER": true, "AZ-MAS": true, "AZ-MI": true, "AZ-NA": true, "AZ-NEF": true,
	"AZ-NV": true, "AZ-NX": true, "AZ-OGU": true, "AZ-ORD": true, "AZ-QAB": true,
	"AZ-QAX": true, "AZ-QAZ": true, "AZ-QBA": true, "AZ-QBI": true, "AZ-QOB": true,
	"AZ-QUS": true, "AZ-SA": true, "AZ-SAB": true, "AZ-SAD": true, "AZ-SAH": true,
	"AZ-SAK": true, "AZ-SAL": true, "AZ-SAR": true, "AZ-SAT": true, "AZ-SBN": true,
	"AZ-SIY": true, "AZ-SKR": true, "AZ-SM": true, "AZ-SMI": true, "AZ-SMX": true,
	"AZ-SR": true, "AZ-SUS": true, "AZ-TAR": true, "AZ-TOV": true, "AZ-UCA": true,
	"AZ-XA": true, "AZ-XAC": true, "AZ-XCI": true, "AZ-XIZ": true, "AZ-XVD": true,
	"AZ-YAR": true, "AZ-YE": true, "AZ-YEV": true, "AZ-ZAN": true, "AZ-ZAQ": true,
	"AZ-ZAR": true, "BA-01": true, "BA-02": true, "BA-03": true, "BA-04": true,
	"BA-05": true, "BA-06": true, "BA-07": true, "BA-08": true, "BA-09": true,
	"BA-10": true, "BA-BIH": true, "BA-BRC": true, "BA-SRP": true, "BB-01": true,
	"BB-02": true, "BB-03": true, "BB-04": true, "BB-05": true, "BB-06": true,
	"BB-07": true, "BB-08": true, "BB-09": true, "BB-10": true, "BB-11": true,
	"BD-01": true, "BD-02": true, "BD-03": true, "BD-04": true, "BD-05": true,
	"BD-06": true, "BD-07": true, "BD-08": true, "BD-09": true, "BD-10": true,
	"BD-11": true, "BD-12": true, "BD-13": true, "BD-14": true, "BD-15": true,
	"BD-16": true, "BD-17": true, "BD-18": true, "BD-19": true, "BD-20": true,
	"BD-21": true, "BD-22": true, "BD-23": true, "BD-24": true, "BD-25": true,
	"BD-26": true, "BD-27": true, "BD-28": true, "BD-29": true, "BD-30": true,
	"BD-31": true, "BD-32": true, "BD-33": true, "BD-34": true, "BD-35": true,
	"BD-36": true, "BD-37": true, "BD-38": true, "BD-39": true, "BD-40": true,
	"BD-41": true, "BD-42": true, "BD-43": true, "BD-44": true, "BD-45": true,
	"BD-46": true, "BD-47": true, "BD-48": true, "BD-49": true, "BD-50": true,
	"BD-51": true, "BD-52": true, "BD-53": true, "BD-54": true, "BD-55": true,
	"BD-56": true, "BD-57": true, "BD-58": true, "BD-59": true, "BD-60": true,
	"BD-61": true, "BD-62": true, "BD-63": true, "BD-64": true, "BD-A": true,
	"BD-B": true, "BD-C": true, "BD-D": true, "BD-E": true, "BD-F": true,
	"BD-G": true, "BE-BRU": true, "BE-VAN": true, "BE-VBR": true, "BE-VLG": true,
	"BE-VLI": true, "BE-VOV": true, "BE-VWV": true, "BE-WAL": true, "BE-WBR": true,
	"BE-WHT": true, "BE-WLG": true, "BE-WLX": true, "BE-WNA": true, "BF-01": true,
	"BF-02": true, "BF-03": true, "BF-04": true, "BF-05": true, "BF-06": true,
	"BF-07": true, "BF-08": true, "BF-09": true, "BF-10": true, "BF-11": true,
	"BF-12": true, "BF-13": true, "BF-BAL": true, "BF-BAM": true, "BF-BAN": true,
	"BF-BAZ": true, "BF-BGR": true, "BF-BLG": true, "BF-BLK": true, "BF-COM": true,
	"BF-GAN": true, "BF-GNA": true, "BF-GOU": true, "BF-HOU": true, "BF-IOB": true,
	"BF-KAD": true, "BF-KEN": true, "BF-KMD": true, "BF-KMP": true, "BF-KOP": true,
	"BF-KOS": true, "BF-KOT": true, "BF-KOW": true, "BF-LER": true, "BF-LOR": true,
	"BF-MOU": true, "BF-NAM": true, "BF-NAO": true, "BF-NAY": true, "BF-NOU": true,
	"BF-OUB": true, "BF-OUD": true, "BF-PAS": true, "BF-PON": true, "BF-SEN": true,
	"BF-SIS": true, "BF-SMT": true, "BF-SNG": true, "BF-SOM": true, "BF-SOR": true,
	"BF-TAP": true, "BF-TUI": true, "BF-YAG": true, "BF-YAT": true, "BF-ZIR": true,
	"BF-ZON": true, "BF-ZOU": true, "BG-01": true, "BG-02": true, "BG-03": true,
	"BG-04": true, "BG-05": true, "BG-06": true, "BG-07": true, "BG-08": true,
	"BG-09": true, "BG-10": true, "BG-11": true, "BG-12": true, "BG-13": true,
	"BG-14": true, "BG-15": true, "BG-16": true, "BG-17": true, "BG-18": true,
	"BG-19": true, "BG-20": true, "BG-21": true, "BG-22": true, "BG-23": true,
	"BG-24": true, "BG-25": true, "BG-26": true, "BG-27": true, "BG-28": true,
	"BH-13": true, "BH-14": true, "BH-15": true, "BH-16": true, "BH-17": true,
	"BI-BB": true, "BI-BL": true, "BI-BM": true, "BI-BR": true, "BI-CA": true,
	"BI-CI": true, "BI-GI": true, "BI-KI": true, "BI-KR": true, "BI-KY": true,
	"BI-MA": true, "BI-MU": true, "BI-MW": true, "BI-NG": true, "BI-RM": true, "BI-RT": true,
	"BI-RY": true, "BJ-AK": true, "BJ-AL": true, "BJ-AQ": true, "BJ-BO": true,
	"BJ-CO": true, "BJ-DO": true, "BJ-KO": true, "BJ-LI": true, "BJ-MO": true,
	"BJ-OU": true, "BJ-PL": true, "BJ-ZO": true, "BN-BE": true, "BN-BM": true,
	"BN-TE": true, "BN-TU": true, "BO-B": true, "BO-C": true, "BO-H": true,
	"BO-L": true, "BO-N": true, "BO-O": true, "BO-P": true, "BO-S": true,
	"BO-T": true, "BQ-BO": true, "BQ-SA": true, "BQ-SE": true, "BR-AC": true,
	"BR-AL": true, "BR-AM": true, "BR-AP": true, "BR-BA": true, "BR-CE": true,
	"BR-DF": true, "BR-ES": true, "BR-FN": true, "BR-GO": true, "BR-MA": true,
	"BR-MG": true, "BR-MS": true, "BR-MT": true, "BR-PA": true, "BR-PB": true,
	"BR-PE": true, "BR-PI": true, "BR-PR": true, "BR-RJ": true, "BR-RN": true,
	"BR-RO": true, "BR-RR": true, "BR-RS": true, "BR-SC": true, "BR-SE": true,
	"BR-SP": true, "BR-TO": true, "BS-AK": true, "BS-BI": true, "BS-BP": true,
	"BS-BY": true, "BS-CE": true, "BS-CI": true, "BS-CK": true, "BS-CO": true,
	"BS-CS": true, "BS-EG": true, "BS-EX": true, "BS-FP": true, "BS-GC": true,
	"BS-HI": true, "BS-HT": true, "BS-IN": true, "BS-LI": true, "BS-MC": true,
	"BS-MG": true, "BS-MI": true, "BS-NE": true, "BS-NO": true, "BS-NP": true, "BS-NS": true,
	"BS-RC": true, "BS-RI": true, "BS-SA": true, "BS-SE": true, "BS-SO": true,
	"BS-SS": true, "BS-SW": true, "BS-WG": true, "BT-11": true, "BT-12": true,
	"BT-13": true, "BT-14": true, "BT-15": true, "BT-21": true, "BT-22": true,
	"BT-23": true, "BT-24": true, "BT-31": true, "BT-32": true, "BT-33": true,
	"BT-34": true, "BT-41": true, "BT-42": true, "BT-43": true, "BT-44": true,
	"BT-45": true, "BT-GA": true, "BT-TY": true, "BW-CE": true, "BW-CH": true, "BW-GH": true,
	"BW-KG": true, "BW-KL": true, "BW-KW": true, "BW-NE": true, "BW-NW": true,
	"BW-SE": true, "BW-SO": true, "BY-BR": true, "BY-HM": true, "BY-HO": true,
	"BY-HR": true, "BY-MA": true, "BY-MI": true, "BY-VI": true, "BZ-BZ": true,
	"BZ-CY": true, "BZ-CZL": true, "BZ-OW": true, "BZ-SC": true, "BZ-TOL": true,
	"CA-AB": true, "CA-BC": true, "CA-MB": true, "CA-NB": true, "CA-NL": true,
	"CA-NS": true, "CA-NT": true, "CA-NU": true, "CA-ON": true, "CA-PE": true,
	"CA-QC": true, "CA-SK": true, "CA-YT": true, "CD-BC": true, "CD-BN": true,
	"CD-EQ": true, "CD-HK": true, "CD-IT": true, "CD-KA": true, "CD-KC": true, "CD-KE": true, "CD-KG": true, "CD-KN": true,
	"CD-KW": true, "CD-KS": true, "CD-LU": true, "CD-MA": true, "CD-NK": true, "CD-OR": true, "CD-SA": true, "CD-SK": true,
	"CD-TA": true, "CD-TO": true, "CF-AC": true, "CF-BB": true, "CF-BGF": true, "CF-BK": true, "CF-HK": true, "CF-HM": true,
	"CF-HS": true, "CF-KB": true, "CF-KG": true, "CF-LB": true, "CF-MB": true,
	"CF-MP": true, "CF-NM": true, "CF-OP": true, "CF-SE": true, "CF-UK": true,
	"CF-VK": true, "CG-11": true, "CG-12": true, "CG-13": true, "CG-14": true,
	"CG-15": true, "CG-16": true, "CG-2": true, "CG-5": true, "CG-7": true, "CG-8": true,
	"CG-9": true, "CG-BZV": true, "CH-AG": true, "CH-AI": true, "CH-AR": true,
	"CH-BE": true, "CH-BL": true, "CH-BS": true, "CH-FR": true, "CH-GE": true,
	"CH-GL": true, "CH-GR": true, "CH-JU": true, "CH-LU": true, "CH-NE": true,
	"CH-NW": true, "CH-OW": true, "CH-SG": true, "CH-SH": true, "CH-SO": true,
	"CH-SZ": true, "CH-TG": true, "CH-TI": true, "CH-UR": true, "CH-VD": true,
	"CH-VS": true, "CH-ZG": true, "CH-ZH": true, "CI-AB": true, "CI-BS": true,
	"CI-CM": true, "CI-DN": true, "CI-GD": true, "CI-LC": true, "CI-LG": true,
	"CI-MG": true, "CI-SM": true, "CI-SV": true, "CI-VB": true, "CI-WR": true,
	"CI-YM": true, "CI-ZZ": true, "CL-AI": true, "CL-AN": true, "CL-AP": true,
	"CL-AR": true, "CL-AT": true, "CL-BI": true, "CL-CO": true, "CL-LI": true,
	"CL-LL": true, "CL-LR": true, "CL-MA": true, "CL-ML": true, "CL-NB": true, "CL-RM": true,
	"CL-TA": true, "CL-VS": true, "CM-AD": true, "CM-CE": true, "CM-EN": true,
	"CM-ES": true, "CM-LT": true, "CM-NO": true, "CM-NW": true, "CM-OU": true,
	"CM-SU": true, "CM-SW": true, "CN-AH": true, "CN-BJ": true, "CN-CQ": true,
	"CN-FJ": true, "CN-GS": true, "CN-GD": true, "CN-GX": true, "CN-GZ": true,
	"CN-HI": true, "CN-HE": true, "CN-HL": true, "CN-HA": true, "CN-HB": true,
	"CN-HN": true, "CN-JS": true, "CN-JX": true, "CN-JL": true, "CN-LN": true,
	"CN-NM": true, "CN-NX": true, "CN-QH": true, "CN-SN": true, "CN-SD": true, "CN-SH": true,
	"CN-SX": true, "CN-SC": true, "CN-TJ": true, "CN-XJ": true, "CN-XZ": true, "CN-YN": true,
	"CN-ZJ": true, "CO-AMA": true, "CO-ANT": true, "CO-ARA": true, "CO-ATL": true,
	"CO-BOL": true, "CO-BOY": true, "CO-CAL": true, "CO-CAQ": true, "CO-CAS": true,
	"CO-CAU": true, "CO-CES": true, "CO-CHO": true, "CO-COR": true, "CO-CUN": true,
	"CO-DC": true, "CO-GUA": true, "CO-GUV": true, "CO-HUI": true, "CO-LAG": true,
	"CO-MAG": true, "CO-MET": true, "CO-NAR": true, "CO-NSA": true, "CO-PUT": true,
	"CO-QUI": true, "CO-RIS": true, "CO-SAN": true, "CO-SAP": true, "CO-SUC": true,
	"CO-TOL": true, "CO-VAC": true, "CO-VAU": true, "CO-VID": true, "CR-A": true,
	"CR-C": true, "CR-G": true, "CR-H": true, "CR-L": true, "CR-P": true,
	"CR-SJ": true, "CU-01": true, "CU-02": true, "CU-03": true, "CU-04": true,
	"CU-05": true, "CU-06": true, "CU-07": true, "CU-08": true, "CU-09": true,
	"CU-10": true, "CU-11": true, "CU-12": true, "CU-13": true, "CU-14": true, "CU-15": true,
	"CU-16": true, "CU-99": true, "CV-B": true, "CV-BR": true, "CV-BV": true, "CV-CA": true,
	"CV-CF": true, "CV-CR": true, "CV-MA": true, "CV-MO": true, "CV-PA": true,
	"CV-PN": true, "CV-PR": true, "CV-RB": true, "CV-RG": true, "CV-RS": true,
	"CV-S": true, "CV-SD": true, "CV-SF": true, "CV-SL": true, "CV-SM": true,
	"CV-SO": true, "CV-SS": true, "CV-SV": true, "CV-TA": true, "CV-TS": true,
	"CY-01": true, "CY-02": true, "CY-03": true, "CY-04": true, "CY-05": true,
	"CY-06": true, "CZ-10": true, "CZ-101": true, "CZ-102": true, "CZ-103": true,
	"CZ-104": true, "CZ-105": true, "CZ-106": true, "CZ-107": true, "CZ-108": true,
	"CZ-109": true, "CZ-110": true, "CZ-111": true, "CZ-112": true, "CZ-113": true,
	"CZ-114": true, "CZ-115": true, "CZ-116": true, "CZ-117": true, "CZ-118": true,
	"CZ-119": true, "CZ-120": true, "CZ-121": true, "CZ-122": true, "CZ-20": true,
	"CZ-201": true, "CZ-202": true, "CZ-203": true, "CZ-204": true, "CZ-205": true,
	"CZ-206": true, "CZ-207": true, "CZ-208": true, "CZ-209": true, "CZ-20A": true,
	"CZ-20B": true, "CZ-20C": true, "CZ-31": true, "CZ-311": true, "CZ-312": true,
	"CZ-313": true, "CZ-314": true, "CZ-315": true, "CZ-316": true, "CZ-317": true,
	"CZ-32": true, "CZ-321": true, "CZ-322": true, "CZ-323": true, "CZ-324": true,
	"CZ-325": true, "CZ-326": true, "CZ-327": true, "CZ-41": true, "CZ-411": true,
	"CZ-412": true, "CZ-413": true, "CZ-42": true, "CZ-421": true, "CZ-422": true,
	"CZ-423": true, "CZ-424": true, "CZ-425": true, "CZ-426": true, "CZ-427": true,
	"CZ-51": true, "CZ-511": true, "CZ-512": true, "CZ-513": true, "CZ-514": true,
	"CZ-52": true, "CZ-521": true, "CZ-522": true, "CZ-523": true, "CZ-524": true,
	"CZ-525": true, "CZ-53": true, "CZ-531": true, "CZ-532": true, "CZ-533": true,
	"CZ-534": true, "CZ-63": true, "CZ-631": true, "CZ-632": true, "CZ-633": true,
	"CZ-634": true, "CZ-635": true, "CZ-64": true, "CZ-641": true, "CZ-642": true,
	"CZ-643": true, "CZ-644": true, "CZ-645": true, "CZ-646": true, "CZ-647": true,
	"CZ-71": true, "CZ-711": true, "CZ-712": true, "CZ-713": true, "CZ-714": true,
	"CZ-715": true, "CZ-72": true, "CZ-721": true, "CZ-722": true, "CZ-723": true,
	"CZ-724": true, "CZ-80": true, "CZ-801": true, "CZ-802": true, "CZ-803": true,
	"CZ-804": true, "CZ-805": true, "CZ-806": true, "DE-BB": true, "DE-BE": true,
	"DE-BW": true, "DE-BY": true, "DE-HB": true, "DE-HE": true, "DE-HH": true,
	"DE-MV": true, "DE-NI": true, "DE-NW": true, "DE-RP": true, "DE-SH": true,
	"DE-SL": true, "DE-SN": true, "DE-ST": true, "DE-TH": true, "DJ-AR": true,
	"DJ-AS": true, "DJ-DI": true, "DJ-DJ": true, "DJ-OB": true, "DJ-TA": true,
	"DK-81": true, "DK-82": true, "DK-83": true, "DK-84": true, "DK-85": true,
	"DM-01": true, "DM-02": true, "DM-03": true, "DM-04": true, "DM-05": true,
	"DM-06": true, "DM-07": true, "DM-08": true, "DM-09": true, "DM-10": true,
	"DO-01": true, "DO-02": true, "DO-03": true, "DO-04": true, "DO-05": true,
	"DO-06": true, "DO-07": true, "DO-08": true, "DO-09": true, "DO-10": true,
	"DO-11": true, "DO-12": true, "DO-13": true, "DO-14": true, "DO-15": true,
	"DO-16": true, "DO-17": true, "DO-18": true, "DO-19": true, "DO-20": true,
	"DO-21": true, "DO-22": true, "DO-23": true, "DO-24": true, "DO-25": true,
	"DO-26": true, "DO-27": true, "DO-28": true, "DO-29": true, "DO-30": true, "DO-31": true,
	"DZ-01": true, "DZ-02": true, "DZ-03": true, "DZ-04": true, "DZ-05": true,
	"DZ-06": true, "DZ-07": true, "DZ-08": true, "DZ-09": true, "DZ-10": true,
	"DZ-11": true, "DZ-12": true, "DZ-13": true, "DZ-14": true, "DZ-15": true,
	"DZ-16": true, "DZ-17": true, "DZ-18": true, "DZ-19": true, "DZ-20": true,
	"DZ-21": true, "DZ-22": true, "DZ-23": true, "DZ-24": true, "DZ-25": true,
	"DZ-26": true, "DZ-27": true, "DZ-28": true, "DZ-29": true, "DZ-30": true,
	"DZ-31": true, "DZ-32": true, "DZ-33": true, "DZ-34": true, "DZ-35": true,
	"DZ-36": true, "DZ-37": true, "DZ-38": true, "DZ-39": true, "DZ-40": true,
	"DZ-41": true, "DZ-42": true, "DZ-43": true, "DZ-44": true, "DZ-45": true,
	"DZ-46": true, "DZ-47": true, "DZ-48": true, "DZ-49": true, "DZ-51": true,
	"DZ-53": true, "DZ-55": true, "DZ-56": true, "DZ-57": true, "EC-A": true, "EC-B": true,
	"EC-C": true, "EC-D": true, "EC-E": true, "EC-F": true, "EC-G": true,
	"EC-H": true, "EC-I": true, "EC-L": true, "EC-M": true, "EC-N": true,
	"EC-O": true, "EC-P": true, "EC-R": true, "EC-S": true, "EC-SD": true,
	"EC-SE": true, "EC-T": true, "EC-U": true, "EC-W": true, "EC-X": true,
	"EC-Y": true, "EC-Z": true, "EE-37": true, "EE-39": true, "EE-44": true, "EE-45": true,
	"EE-49": true, "EE-50": true, "EE-51": true, "EE-52": true, "EE-56": true, "EE-57": true,
	"EE-59": true, "EE-60": true, "EE-64": true, "EE-65": true, "EE-67": true, "EE-68": true,
	"EE-70": true, "EE-71": true, "EE-74": true, "EE-78": true, "EE-79": true, "EE-81": true, "EE-82": true,
	"EE-84": true, "EE-86": true, "EE-87": true, "EG-ALX": true, "EG-ASN": true, "EG-AST": true,
	"EG-BA": true, "EG-BH": true, "EG-BNS": true, "EG-C": true, "EG-DK": true,
	"EG-DT": true, "EG-FYM": true, "EG-GH": true, "EG-GZ": true, "EG-HU": true,
	"EG-IS": true, "EG-JS": true, "EG-KB": true, "EG-KFS": true, "EG-KN": true,
	"EG-LX": true, "EG-MN": true, "EG-MNF": true, "EG-MT": true, "EG-PTS": true, "EG-SHG": true,
	"EG-SHR": true, "EG-SIN": true, "EG-SU": true, "EG-SUZ": true, "EG-WAD": true,
	"ER-AN": true, "ER-DK": true, "ER-DU": true, "ER-GB": true, "ER-MA": true,
	"ER-SK": true, "ES-A": true, "ES-AB": true, "ES-AL": true, "ES-AN": true,
	"ES-AR": true, "ES-AS": true, "ES-AV": true, "ES-B": true, "ES-BA": true,
	"ES-BI": true, "ES-BU": true, "ES-C": true, "ES-CA": true, "ES-CB": true,
	"ES-CC": true, "ES-CE": true, "ES-CL": true, "ES-CM": true, "ES-CN": true,
	"ES-CO": true, "ES-CR": true, "ES-CS": true, "ES-CT": true, "ES-CU": true,
	"ES-EX": true, "ES-GA": true, "ES-GC": true, "ES-GI": true, "ES-GR": true,
	"ES-GU": true, "ES-H": true, "ES-HU": true, "ES-IB": true, "ES-J": true,
	"ES-L": true, "ES-LE": true, "ES-LO": true, "ES-LU": true, "ES-M": true,
	"ES-MA": true, "ES-MC": true, "ES-MD": true, "ES-ML": true, "ES-MU": true,
	"ES-NA": true, "ES-NC": true, "ES-O": true, "ES-OR": true, "ES-P": true,
	"ES-PM": true, "ES-PO": true, "ES-PV": true, "ES-RI": true, "ES-S": true,
	"ES-SA": true, "ES-SE": true, "ES-SG": true, "ES-SO": true, "ES-SS": true,
	"ES-T": true, "ES-TE": true, "ES-TF": true, "ES-TO": true, "ES-V": true,
	"ES-VA": true, "ES-VC": true, "ES-VI": true, "ES-Z": true, "ES-ZA": true,
	"ET-AA": true, "ET-AF": true, "ET-AM": true, "ET-BE": true, "ET-DD": true,
	"ET-GA": true, "ET-HA": true, "ET-OR": true, "ET-SN": true, "ET-SO": true,
	"ET-TI": true, "FI-01": true, "FI-02": true, "FI-03": true, "FI-04": true,
	"FI-05": true, "FI-06": true, "FI-07": true, "FI-08": true, "FI-09": true,
	"FI-10": true, "FI-11": true, "FI-12": true, "FI-13": true, "FI-14": true,
	"FI-15": true, "FI-16": true, "FI-17": true, "FI-18": true, "FI-19": true,
	"FJ-C": true, "FJ-E": true, "FJ-N": true, "FJ-R": true, "FJ-W": true,
	"FM-KSA": true, "FM-PNI": true, "FM-TRK": true, "FM-YAP": true, "FR-01": true,
	"FR-02": true, "FR-03": true, "FR-04": true, "FR-05": true, "FR-06": true,
	"FR-07": true, "FR-08": true, "FR-09": true, "FR-10": true, "FR-11": true,
	"FR-12": true, "FR-13": true, "FR-14": true, "FR-15": true, "FR-16": true,
	"FR-17": true, "FR-18": true, "FR-19": true, "FR-20R": true, "FR-21": true, "FR-22": true,
	"FR-23": true, "FR-24": true, "FR-25": true, "FR-26": true, "FR-27": true,
	"FR-28": true, "FR-29": true, "FR-2A": true, "FR-2B": true, "FR-30": true,
	"FR-31": true, "FR-32": true, "FR-33": true, "FR-34": true, "FR-35": true,
	"FR-36": true, "FR-37": true, "FR-38": true, "FR-39": true, "FR-40": true,
	"FR-41": true, "FR-42": true, "FR-43": true, "FR-44": true, "FR-45": true,
	"FR-46": true, "FR-47": true, "FR-48": true, "FR-49": true, "FR-50": true,
	"FR-51": true, "FR-52": true, "FR-53": true, "FR-54": true, "FR-55": true,
	"FR-56": true, "FR-57": true, "FR-58": true, "FR-59": true, "FR-60": true,
	"FR-61": true, "FR-62": true, "FR-63": true, "FR-64": true, "FR-65": true,
	"FR-66": true, "FR-67": true, "FR-68": true, "FR-69": true, "FR-70": true,
	"FR-71": true, "FR-72": true, "FR-73": true, "FR-74": true, "FR-75": true,
	"FR-76": true, "FR-77": true, "FR-78": true, "FR-79": true, "FR-80": true,
	"FR-81": true, "FR-82": true, "FR-83": true, "FR-84": true, "FR-85": true,
	"FR-86": true, "FR-87": true, "FR-88": true, "FR-89": true, "FR-90": true,
	"FR-91": true, "FR-92": true, "FR-93": true, "FR-94": true, "FR-95": true,
	"FR-ARA": true, "FR-BFC": true, "FR-BL": true, "FR-BRE": true, "FR-COR": true,
	"FR-CP": true, "FR-CVL": true, "FR-GES": true, "FR-GF": true, "FR-GP": true,
	"FR-GUA": true, "FR-HDF": true, "FR-IDF": true, "FR-LRE": true, "FR-MAY": true,
	"FR-MF": true, "FR-MQ": true, "FR-NAQ": true, "FR-NC": true, "FR-NOR": true,
	"FR-OCC": true, "FR-PAC": true, "FR-PDL": true, "FR-PF": true, "FR-PM": true,
	"FR-RE": true, "FR-TF": true, "FR-WF": true, "FR-YT": true, "GA-1": true,
	"GA-2": true, "GA-3": true, "GA-4": true, "GA-5": true, "GA-6": true,
	"GA-7": true, "GA-8": true, "GA-9": true, "GB-ABC": true, "GB-ABD": true,
	"GB-ABE": true, "GB-AGB": true, "GB-AGY": true, "GB-AND": true, "GB-ANN": true,
	"GB-ANS": true, "GB-BAS": true, "GB-BBD": true, "GB-BDF": true, "GB-BDG": true,
	"GB-BEN": true, "GB-BEX": true, "GB-BFS": true, "GB-BGE": true, "GB-BGW": true,
	"GB-BIR": true, "GB-BKM": true, "GB-BMH": true, "GB-BNE": true, "GB-BNH": true,
	"GB-BNS": true, "GB-BOL": true, "GB-BPL": true, "GB-BRC": true, "GB-BRD": true,
	"GB-BRY": true, "GB-BST": true, "GB-BUR": true, "GB-CAM": true, "GB-CAY": true,
	"GB-CBF": true, "GB-CCG": true, "GB-CGN": true, "GB-CHE": true, "GB-CHW": true,
	"GB-CLD": true, "GB-CLK": true, "GB-CMA": true, "GB-CMD": true, "GB-CMN": true,
	"GB-CON": true, "GB-COV": true, "GB-CRF": true, "GB-CRY": true, "GB-CWY": true,
	"GB-DAL": true, "GB-DBY": true, "GB-DEN": true, "GB-DER": true, "GB-DEV": true,
	"GB-DGY": true, "GB-DNC": true, "GB-DND": true, "GB-DOR": true, "GB-DRS": true,
	"GB-DUD": true, "GB-DUR": true, "GB-EAL": true, "GB-EAW": true, "GB-EAY": true,
	"GB-EDH": true, "GB-EDU": true, "GB-ELN": true, "GB-ELS": true, "GB-ENF": true,
	"GB-ENG": true, "GB-ERW": true, "GB-ERY": true, "GB-ESS": true, "GB-ESX": true,
	"GB-FAL": true, "GB-FIF": true, "GB-FLN": true, "GB-FMO": true, "GB-GAT": true,
	"GB-GBN": true, "GB-GLG": true, "GB-GLS": true, "GB-GRE": true, "GB-GWN": true,
	"GB-HAL": true, "GB-HAM": true, "GB-HAV": true, "GB-HCK": true, "GB-HEF": true,
	"GB-HIL": true, "GB-HLD": true, "GB-HMF": true, "GB-HNS": true, "GB-HPL": true,
	"GB-HRT": true, "GB-HRW": true, "GB-HRY": true, "GB-IOS": true, "GB-IOW": true,
	"GB-ISL": true, "GB-IVC": true, "GB-KEC": true, "GB-KEN": true, "GB-KHL": true,
	"GB-KIR": true, "GB-KTT": true, "GB-KWL": true, "GB-LAN": true, "GB-LBC": true,
	"GB-LBH": true, "GB-LCE": true, "GB-LDS": true, "GB-LEC": true, "GB-LEW": true,
	"GB-LIN": true, "GB-LIV": true, "GB-LND": true, "GB-LUT": true, "GB-MAN": true,
	"GB-MDB": true, "GB-MDW": true, "GB-MEA": true, "GB-MIK": true, "GD-01": true,
	"GB-MLN": true, "GB-MON": true, "GB-MRT": true, "GB-MRY": true, "GB-MTY": true,
	"GB-MUL": true, "GB-NAY": true, "GB-NBL": true, "GB-NEL": true, "GB-NET": true,
	"GB-NFK": true, "GB-NGM": true, "GB-NIR": true, "GB-NLK": true, "GB-NLN": true,
	"GB-NMD": true, "GB-NSM": true, "GB-NTH": true, "GB-NTL": true, "GB-NTT": true,
	"GB-NTY": true, "GB-NWM": true, "GB-NWP": true, "GB-NYK": true, "GB-OLD": true,
	"GB-ORK": true, "GB-OXF": true, "GB-PEM": true, "GB-PKN": true, "GB-PLY": true,
	"GB-POL": true, "GB-POR": true, "GB-POW": true, "GB-PTE": true, "GB-RCC": true,
	"GB-RCH": true, "GB-RCT": true, "GB-RDB": true, "GB-RDG": true, "GB-RFW": true,
	"GB-RIC": true, "GB-ROT": true, "GB-RUT": true, "GB-SAW": true, "GB-SAY": true,
	"GB-SCB": true, "GB-SCT": true, "GB-SFK": true, "GB-SFT": true, "GB-SGC": true,
	"GB-SHF": true, "GB-SHN": true, "GB-SHR": true, "GB-SKP": true, "GB-SLF": true,
	"GB-SLG": true, "GB-SLK": true, "GB-SND": true, "GB-SOL": true, "GB-SOM": true,
	"GB-SOS": true, "GB-SRY": true, "GB-STE": true, "GB-STG": true, "GB-STH": true,
	"GB-STN": true, "GB-STS": true, "GB-STT": true, "GB-STY": true, "GB-SWA": true,
	"GB-SWD": true, "GB-SWK": true, "GB-TAM": true, "GB-TFW": true, "GB-THR": true,
	"GB-TOB": true, "GB-TOF": true, "GB-TRF": true, "GB-TWH": true, "GB-UKM": true,
	"GB-VGL": true, "GB-WAR": true, "GB-WBK": true, "GB-WDU": true, "GB-WFT": true,
	"GB-WGN": true, "GB-WIL": true, "GB-WKF": true, "GB-WLL": true, "GB-WLN": true,
	"GB-WLS": true, "GB-WLV": true, "GB-WND": true, "GB-WNM": true, "GB-WOK": true,
	"GB-WOR": true, "GB-WRL": true, "GB-WRT": true, "GB-WRX": true, "GB-WSM": true,
	"GB-WSX": true, "GB-YOR": true, "GB-ZET": true, "GD-02": true, "GD-03": true,
	"GD-04": true, "GD-05": true, "GD-06": true, "GD-10": true, "GE-AB": true,
	"GE-AJ": true, "GE-GU": true, "GE-IM": true, "GE-KA": true, "GE-KK": true,
	"GE-MM": true, "GE-RL": true, "GE-SJ": true, "GE-SK": true, "GE-SZ": true,
	"GE-TB": true, "GH-AA": true, "GH-AH": true, "GH-AF": true, "GH-BA": true, "GH-BO": true, "GH-BE": true, "GH-CP": true,
	"GH-EP": true, "GH-NP": true, "GH-TV": true, "GH-UE": true, "GH-UW": true,
	"GH-WP": true, "GL-AV": true, "GL-KU": true, "GL-QA": true, "GL-QT": true, "GL-QE": true, "GL-SM": true,
	"GM-B": true, "GM-L": true, "GM-M": true, "GM-N": true, "GM-U": true,
	"GM-W": true, "GN-B": true, "GN-BE": true, "GN-BF": true, "GN-BK": true,
	"GN-C": true, "GN-CO": true, "GN-D": true, "GN-DB": true, "GN-DI": true,
	"GN-DL": true, "GN-DU": true, "GN-F": true, "GN-FA": true, "GN-FO": true,
	"GN-FR": true, "GN-GA": true, "GN-GU": true, "GN-K": true, "GN-KA": true,
	"GN-KB": true, "GN-KD": true, "GN-KE": true, "GN-KN": true, "GN-KO": true,
	"GN-KS": true, "GN-L": true, "GN-LA": true, "GN-LE": true, "GN-LO": true,
	"GN-M": true, "GN-MC": true, "GN-MD": true, "GN-ML": true, "GN-MM": true,
	"GN-N": true, "GN-NZ": true, "GN-PI": true, "GN-SI": true, "GN-TE": true,
	"GN-TO": true, "GN-YO": true, "GQ-AN": true, "GQ-BN": true, "GQ-BS": true,
	"GQ-C": true, "GQ-CS": true, "GQ-I": true, "GQ-KN": true, "GQ-LI": true,
	"GQ-WN": true, "GR-01": true, "GR-03": true, "GR-04": true, "GR-05": true,
	"GR-06": true, "GR-07": true, "GR-11": true, "GR-12": true, "GR-13": true,
	"GR-14": true, "GR-15": true, "GR-16": true, "GR-17": true, "GR-21": true,
	"GR-22": true, "GR-23": true, "GR-24": true, "GR-31": true, "GR-32": true,
	"GR-33": true, "GR-34": true, "GR-41": true, "GR-42": true, "GR-43": true,
	"GR-44": true, "GR-51": true, "GR-52": true, "GR-53": true, "GR-54": true,
	"GR-55": true, "GR-56": true, "GR-57": true, "GR-58": true, "GR-59": true,
	"GR-61": true, "GR-62": true, "GR-63": true, "GR-64": true, "GR-69": true,
	"GR-71": true, "GR-72": true, "GR-73": true, "GR-81": true, "GR-82": true,
	"GR-83": true, "GR-84": true, "GR-85": true, "GR-91": true, "GR-92": true,
	"GR-93": true, "GR-94": true, "GR-A": true, "GR-A1": true, "GR-B": true,
	"GR-C": true, "GR-D": true, "GR-E": true, "GR-F": true, "GR-G": true,
	"GR-H": true, "GR-I": true, "GR-J": true, "GR-K": true, "GR-L": true,
	"GR-M": true, "GT-01": true, "GT-02": true, "GT-03": true, "GT-04": true,
	"GT-05": true, "GT-06": true, "GT-07": true, "GT-08": true, "GT-09": true,
	"GT-10": true, "GT-11": true, "GT-12": true, "GT-13": true, "GT-14": true,
	"GT-15": true, "GT-16": true, "GT-17": true, "GT-18": true, "GT-19": true,
	"GT-20": true, "GT-21": true, "GT-22": true, "GW-BA": true, "GW-BL": true,
	"GW-BM": true, "GW-BS": true, "GW-CA": true, "GW-GA": true, "GW-L": true,
	"GW-N": true, "GW-OI": true, "GW-QU": true, "GW-S": true, "GW-TO": true,
	"GY-BA": true, "GY-CU": true, "GY-DE": true, "GY-EB": true, "GY-ES": true,
	"GY-MA": true, "GY-PM": true, "GY-PT": true, "GY-UD": true, "GY-UT": true,
	"HN-AT": true, "HN-CH": true, "HN-CL": true, "HN-CM": true, "HN-CP": true,
	"HN-CR": true, "HN-EP": true, "HN-FM": true, "HN-GD": true, "HN-IB": true,
	"HN-IN": true, "HN-LE": true, "HN-LP": true, "HN-OC": true, "HN-OL": true,
	"HN-SB": true, "HN-VA": true, "HN-YO": true, "HR-01": true, "HR-02": true,
	"HR-03": true, "HR-04": true, "HR-05": true, "HR-06": true, "HR-07": true,
	"HR-08": true, "HR-09": true, "HR-10": true, "HR-11": true, "HR-12": true,
	"HR-13": true, "HR-14": true, "HR-15": true, "HR-16": true, "HR-17": true,
	"HR-18": true, "HR-19": true, "HR-20": true, "HR-21": true, "HT-AR": true,
	"HT-CE": true, "HT-GA": true, "HT-ND": true, "HT-NE": true, "HT-NO": true, "HT-NI": true,
	"HT-OU": true, "HT-SD": true, "HT-SE": true, "HU-BA": true, "HU-BC": true,
	"HU-BE": true, "HU-BK": true, "HU-BU": true, "HU-BZ": true, "HU-CS": true,
	"HU-DE": true, "HU-DU": true, "HU-EG": true, "HU-ER": true, "HU-FE": true,
	"HU-GS": true, "HU-GY": true, "HU-HB": true, "HU-HE": true, "HU-HV": true,
	"HU-JN": true, "HU-KE": true, "HU-KM": true, "HU-KV": true, "HU-MI": true,
	"HU-NK": true, "HU-NO": true, "HU-NY": true, "HU-PE": true, "HU-PS": true,
	"HU-SD": true, "HU-SF": true, "HU-SH": true, "HU-SK": true, "HU-SN": true,
	"HU-SO": true, "HU-SS": true, "HU-ST": true, "HU-SZ": true, "HU-TB": true,
	"HU-TO": true, "HU-VA": true, "HU-VE": true, "HU-VM": true, "HU-ZA": true,
	"HU-ZE": true, "ID-AC": true, "ID-BA": true, "ID-BB": true, "ID-BE": true,
	"ID-BT": true, "ID-GO": true, "ID-IJ": true, "ID-JA": true, "ID-JB": true,
	"ID-JI": true, "ID-JK": true, "ID-JT": true, "ID-JW": true, "ID-KA": true,
	"ID-KB": true, "ID-KI": true, "ID-KU": true, "ID-KR": true, "ID-KS": true,
	"ID-KT": true, "ID-LA": true, "ID-MA": true, "ID-ML": true, "ID-MU": true,
	"ID-NB": true, "ID-NT": true, "ID-NU": true, "ID-PA": true, "ID-PB": true,
	"ID-PE": true, "ID-PP": true, "ID-PS": true, "ID-PT": true, "ID-RI": true,
	"ID-SA": true, "ID-SB": true, "ID-SG": true, "ID-SL": true, "ID-SM": true,
	"ID-SN": true, "ID-SR": true, "ID-SS": true, "ID-ST": true, "ID-SU": true,
	"ID-YO": true, "IE-C": true, "IE-CE": true, "IE-CN": true, "IE-CO": true,
	"IE-CW": true, "IE-D": true, "IE-DL": true, "IE-G": true, "IE-KE": true,
	"IE-KK": true, "IE-KY": true, "IE-L": true, "IE-LD": true, "IE-LH": true,
	"IE-LK": true, "IE-LM": true, "IE-LS": true, "IE-M": true, "IE-MH": true,
	"IE-MN": true, "IE-MO": true, "IE-OY": true, "IE-RN": true, "IE-SO": true,
	"IE-TA": true, "IE-U": true, "IE-WD": true, "IE-WH": true, "IE-WW": true,
	"IE-WX": true, "IL-D": true, "IL-HA": true, "IL-JM": true, "IL-M": true,
	"IL-TA": true, "IL-Z": true, "IN-AN": true, "IN-AP": true, "IN-AR": true,
	"IN-AS": true, "IN-BR": true, "IN-CH": true, "IN-CT": true, "IN-DH": true,
	"IN-DL": true, "IN-DN": true, "IN-GA": true, "IN-GJ": true, "IN-HP": true,
	"IN-HR": true, "IN-JH": true, "IN-JK": true, "IN-KA": true, "IN-KL": true,
	"IN-LD": true, "IN-MH": true, "IN-ML": true, "IN-MN": true, "IN-MP": true,
	"IN-MZ": true, "IN-NL": true, "IN-TG": true, "IN-OR": true, "IN-PB": true, "IN-PY": true,
	"IN-RJ": true, "IN-SK": true, "IN-TN": true, "IN-TR": true, "IN-UP": true,
	"IN-UT": true, "IN-WB": true, "IQ-AN": true, "IQ-AR": true, "IQ-BA": true,
	"IQ-BB": true, "IQ-BG": true, "IQ-DA": true, "IQ-DI": true, "IQ-DQ": true,
	"IQ-KA": true, "IQ-KI": true, "IQ-MA": true, "IQ-MU": true, "IQ-NA": true, "IQ-NI": true,
	"IQ-QA": true, "IQ-SD": true, "IQ-SW": true, "IQ-SU": true, "IQ-TS": true, "IQ-WA": true,
	"IR-00": true, "IR-01": true, "IR-02": true, "IR-03": true, "IR-04": true, "IR-05": true,
	"IR-06": true, "IR-07": true, "IR-08": true, "IR-09": true, "IR-10": true, "IR-11": true,
	"IR-12": true, "IR-13": true, "IR-14": true, "IR-15": true, "IR-16": true,
	"IR-17": true, "IR-18": true, "IR-19": true, "IR-20": true, "IR-21": true,
	"IR-22": true, "IR-23": true, "IR-24": true, "IR-25": true, "IR-26": true,
	"IR-27": true, "IR-28": true, "IR-29": true, "IR-30": true, "IR-31": true,
	"IS-0": true, "IS-1": true, "IS-2": true, "IS-3": true, "IS-4": true,
	"IS-5": true, "IS-6": true, "IS-7": true, "IS-8": true, "IT-21": true,
	"IT-23": true, "IT-25": true, "IT-32": true, "IT-34": true, "IT-36": true,
	"IT-42": true, "IT-45": true, "IT-52": true, "IT-55": true, "IT-57": true,
	"IT-62": true, "IT-65": true, "IT-67": true, "IT-72": true, "IT-75": true,
	"IT-77": true, "IT-78": true, "IT-82": true, "IT-88": true, "IT-AG": true,
	"IT-AL": true, "IT-AN": true, "IT-AO": true, "IT-AP": true, "IT-AQ": true,
	"IT-AR": true, "IT-AT": true, "IT-AV": true, "IT-BA": true, "IT-BG": true,
	"IT-BI": true, "IT-BL": true, "IT-BN": true, "IT-BO": true, "IT-BR": true,
	"IT-BS": true, "IT-BT": true, "IT-BZ": true, "IT-CA": true, "IT-CB": true,
	"IT-CE": true, "IT-CH": true, "IT-CI": true, "IT-CL": true, "IT-CN": true,
	"IT-CO": true, "IT-CR": true, "IT-CS": true, "IT-CT": true, "IT-CZ": true,
	"IT-EN": true, "IT-FC": true, "IT-FE": true, "IT-FG": true, "IT-FI": true,
	"IT-FM": true, "IT-FR": true, "IT-GE": true, "IT-GO": true, "IT-GR": true,
	"IT-IM": true, "IT-IS": true, "IT-KR": true, "IT-LC": true, "IT-LE": true,
	"IT-LI": true, "IT-LO": true, "IT-LT": true, "IT-LU": true, "IT-MB": true,
	"IT-MC": true, "IT-ME": true, "IT-MI": true, "IT-MN": true, "IT-MO": true,
	"IT-MS": true, "IT-MT": true, "IT-NA": true, "IT-NO": true, "IT-NU": true,
	"IT-OG": true, "IT-OR": true, "IT-OT": true, "IT-PA": true, "IT-PC": true,
	"IT-PD": true, "IT-PE": true, "IT-PG": true, "IT-PI": true, "IT-PN": true,
	"IT-PO": true, "IT-PR": true, "IT-PT": true, "IT-PU": true, "IT-PV": true,
	"IT-PZ": true, "IT-RA": true, "IT-RC": true, "IT-RE": true, "IT-RG": true,
	"IT-RI": true, "IT-RM": true, "IT-RN": true, "IT-RO": true, "IT-SA": true,
	"IT-SI": true, "IT-SO": true, "IT-SP": true, "IT-SR": true, "IT-SS": true,
	"IT-SV": true, "IT-TA": true, "IT-TE": true, "IT-TN": true, "IT-TO": true,
	"IT-TP": true, "IT-TR": true, "IT-TS": true, "IT-TV": true, "IT-UD": true,
	"IT-VA": true, "IT-VB": true, "IT-VC": true, "IT-VE": true, "IT-VI": true,
	"IT-VR": true, "IT-VS": true, "IT-VT": true, "IT-VV": true, "JM-01": true,
	"JM-02": true, "JM-03": true, "JM-04": true, "JM-05": true, "JM-06": true,
	"JM-07": true, "JM-08": true, "JM-09": true, "JM-10": true, "JM-11": true,
	"JM-12": true, "JM-13": true, "JM-14": true, "JO-AJ": true, "JO-AM": true,
	"JO-AQ": true, "JO-AT": true, "JO-AZ": true, "JO-BA": true, "JO-IR": true,
	"JO-JA": true, "JO-KA": true, "JO-MA": true, "JO-MD": true, "JO-MN": true,
	"JP-01": true, "JP-02": true, "JP-03": true, "JP-04": true, "JP-05": true,
	"JP-06": true, "JP-07": true, "JP-08": true, "JP-09": true, "JP-10": true,
	"JP-11": true, "JP-12": true, "JP-13": true, "JP-14": true, "JP-15": true,
	"JP-16": true, "JP-17": true, "JP-18": true, "JP-19": true, "JP-20": true,
	"JP-21": true, "JP-22": true, "JP-23": true, "JP-24": true, "JP-25": true,
	"JP-26": true, "JP-27": true, "JP-28": true, "JP-29": true, "JP-30": true,
	"JP-31": true, "JP-32": true, "JP-33": true, "JP-34": true, "JP-35": true,
	"JP-36": true, "JP-37": true, "JP-38": true, "JP-39": true, "JP-40": true,
	"JP-41": true, "JP-42": true, "JP-43": true, "JP-44": true, "JP-45": true,
	"JP-46": true, "JP-47": true, "KE-01": true, "KE-02": true, "KE-03": true,
	"KE-04": true, "KE-05": true, "KE-06": true, "KE-07": true, "KE-08": true,
	"KE-09": true, "KE-10": true, "KE-11": true, "KE-12": true, "KE-13": true,
	"KE-14": true, "KE-15": true, "KE-16": true, "KE-17": true, "KE-18": true,
	"KE-19": true, "KE-20": true, "KE-21": true, "KE-22": true, "KE-23": true,
	"KE-24": true, "KE-25": true, "KE-26": true, "KE-27": true, "KE-28": true,
	"KE-29": true, "KE-30": true, "KE-31": true, "KE-32": true, "KE-33": true,
	"KE-34": true, "KE-35": true, "KE-36": true, "KE-37": true, "KE-38": true,
	"KE-39": true, "KE-40": true, "KE-41": true, "KE-42": true, "KE-43": true,
	"KE-44": true, "KE-45": true, "KE-46": true, "KE-47": true, "KG-B": true,
	"KG-C": true, "KG-GB": true, "KG-GO": true, "KG-J": true, "KG-N": true, "KG-O": true,
	"KG-T": true, "KG-Y": true, "KH-1": true, "KH-10": true, "KH-11": true,
	"KH-12": true, "KH-13": true, "KH-14": true, "KH-15": true, "KH-16": true,
	"KH-17": true, "KH-18": true, "KH-19": true, "KH-2": true, "KH-20": true,
	"KH-21": true, "KH-22": true, "KH-23": true, "KH-24": true, "KH-3": true,
	"KH-4": true, "KH-5": true, "KH-6": true, "KH-7": true, "KH-8": true,
	"KH-9": true, "KI-G": true, "KI-L": true, "KI-P": true, "KM-A": true,
	"KM-G": true, "KM-M": true, "KN-01": true, "KN-02": true, "KN-03": true,
	"KN-04": true, "KN-05": true, "KN-06": true, "KN-07": true, "KN-08": true,
	"KN-09": true, "KN-10": true, "KN-11": true, "KN-12": true, "KN-13": true,
	"KN-15": true, "KN-K": true, "KN-N": true, "KP-01": true, "KP-02": true,
	"KP-03": true, "KP-04": true, "KP-05": true, "KP-06": true, "KP-07": true,
	"KP-08": true, "KP-09": true, "KP-10": true, "KP-13": true, "KR-11": true,
	"KR-26": true, "KR-27": true, "KR-28": true, "KR-29": true, "KR-30": true,
	"KR-31": true, "KR-41": true, "KR-42": true, "KR-43": true, "KR-44": true,
	"KR-45": true, "KR-46": true, "KR-47": true, "KR-48": true, "KR-49": true,
	"KW-AH": true, "KW-FA": true, "KW-HA": true, "KW-JA": true, "KW-KU": true,
	"KW-MU": true, "KZ-10": true, "KZ-75": true, "KZ-19": true, "KZ-11": true,
	"KZ-15": true, "KZ-71": true, "KZ-23": true, "KZ-27": true, "KZ-47": true,
	"KZ-55": true, "KZ-35": true, "KZ-39": true, "KZ-43": true, "KZ-63": true,
	"KZ-79": true, "KZ-59": true, "KZ-61": true, "KZ-62": true, "KZ-31": true,
	"KZ-33": true, "LA-AT": true, "LA-BK": true, "LA-BL": true,
	"LA-CH": true, "LA-HO": true, "LA-KH": true, "LA-LM": true, "LA-LP": true,
	"LA-OU": true, "LA-PH": true, "LA-SL": true, "LA-SV": true, "LA-VI": true,
	"LA-VT": true, "LA-XA": true, "LA-XE": true, "LA-XI": true, "LA-XS": true,
	"LB-AK": true, "LB-AS": true, "LB-BA": true, "LB-BH": true, "LB-BI": true,
	"LB-JA": true, "LB-JL": true, "LB-NA": true, "LC-01": true, "LC-02": true,
	"LC-03": true, "LC-05": true, "LC-06": true, "LC-07": true, "LC-08": true,
	"LC-10": true, "LC-11": true, "LI-01": true, "LI-02": true,
	"LI-03": true, "LI-04": true, "LI-05": true, "LI-06": true, "LI-07": true,
	"LI-08": true, "LI-09": true, "LI-10": true, "LI-11": true, "LK-1": true,
	"LK-11": true, "LK-12": true, "LK-13": true, "LK-2": true, "LK-21": true,
	"LK-22": true, "LK-23": true, "LK-3": true, "LK-31": true, "LK-32": true,
	"LK-33": true, "LK-4": true, "LK-41": true, "LK-42": true, "LK-43": true,
	"LK-44": true, "LK-45": true, "LK-5": true, "LK-51": true, "LK-52": true,
	"LK-53": true, "LK-6": true, "LK-61": true, "LK-62": true, "LK-7": true,
	"LK-71": true, "LK-72": true, "LK-8": true, "LK-81": true, "LK-82": true,
	"LK-9": true, "LK-91": true, "LK-92": true, "LR-BG": true, "LR-BM": true,
	"LR-CM": true, "LR-GB": true, "LR-GG": true, "LR-GK": true, "LR-LO": true,
	"LR-MG": true, "LR-MO": true, "LR-MY": true, "LR-NI": true, "LR-RI": true,
	"LR-SI": true, "LS-A": true, "LS-B": true, "LS-C": true, "LS-D": true,
	"LS-E": true, "LS-F": true, "LS-G": true, "LS-H": true, "LS-J": true,
	"LS-K": true, "LT-AL": true, "LT-KL": true, "LT-KU": true, "LT-MR": true,
	"LT-PN": true, "LT-SA": true, "LT-TA": true, "LT-TE": true, "LT-UT": true,
	"LT-VL": true, "LU-CA": true, "LU-CL": true, "LU-DI": true, "LU-EC": true,
	"LU-ES": true, "LU-GR": true, "LU-LU": true, "LU-ME": true, "LU-RD": true,
	"LU-RM": true, "LU-VD": true, "LU-WI": true, "LU-D": true, "LU-G": true, "LU-L": true,
	"LV-001": true, "LV-111": true, "LV-112": true, "LV-113": true,
	"LV-002": true, "LV-003": true, "LV-004": true, "LV-005": true, "LV-006": true,
	"LV-007": true, "LV-008": true, "LV-009": true, "LV-010": true, "LV-011": true,
	"LV-012": true, "LV-013": true, "LV-014": true, "LV-015": true, "LV-016": true,
	"LV-017": true, "LV-018": true, "LV-019": true, "LV-020": true, "LV-021": true,
	"LV-022": true, "LV-023": true, "LV-024": true, "LV-025": true, "LV-026": true,
	"LV-027": true, "LV-028": true, "LV-029": true, "LV-030": true, "LV-031": true,
	"LV-032": true, "LV-033": true, "LV-034": true, "LV-035": true, "LV-036": true,
	"LV-037": true, "LV-038": true, "LV-039": true, "LV-040": true, "LV-041": true,
	"LV-042": true, "LV-043": true, "LV-044": true, "LV-045": true, "LV-046": true,
	"LV-047": true, "LV-048": true, "LV-049": true, "LV-050": true, "LV-051": true,
	"LV-052": true, "LV-053": true, "LV-054": true, "LV-055": true, "LV-056": true,
	"LV-057": true, "LV-058": true, "LV-059": true, "LV-060": true, "LV-061": true,
	"LV-062": true, "LV-063": true, "LV-064": true, "LV-065": true, "LV-066": true,
	"LV-067": true, "LV-068": true, "LV-069": true, "LV-070": true, "LV-071": true,
	"LV-072": true, "LV-073": true, "LV-074": true, "LV-075": true, "LV-076": true,
	"LV-077": true, "LV-078": true, "LV-079": true, "LV-080": true, "LV-081": true,
	"LV-082": true, "LV-083": true, "LV-084": true, "LV-085": true, "LV-086": true,
	"LV-087": true, "LV-088": true, "LV-089": true, "LV-090": true, "LV-091": true,
	"LV-092": true, "LV-093": true, "LV-094": true, "LV-095": true, "LV-096": true,
	"LV-097": true, "LV-098": true, "LV-099": true, "LV-100": true, "LV-101": true,
	"LV-102": true, "LV-103": true, "LV-104": true, "LV-105": true, "LV-106": true,
	"LV-107": true, "LV-108": true, "LV-109": true, "LV-110": true, "LV-DGV": true,
	"LV-JEL": true, "LV-JKB": true, "LV-JUR": true, "LV-LPX": true, "LV-REZ": true,
	"LV-RIX": true, "LV-VEN": true, "LV-VMR": true, "LY-BA": true, "LY-BU": true,
	"LY-DR": true, "LY-GT": true, "LY-JA": true, "LY-JB": true, "LY-JG": true,
	"LY-JI": true, "LY-JU": true, "LY-KF": true, "LY-MB": true, "LY-MI": true,
	"LY-MJ": true, "LY-MQ": true, "LY-NL": true, "LY-NQ": true, "LY-SB": true,
	"LY-SR": true, "LY-TB": true, "LY-WA": true, "LY-WD": true, "LY-WS": true,
	"LY-ZA": true, "MA-01": true, "MA-02": true, "MA-03": true, "MA-04": true,
	"MA-05": true, "MA-06": true, "MA-07": true, "MA-08": true, "MA-09": true,
	"MA-10": true, "MA-11": true, "MA-12": true, "MA-13": true, "MA-14": true,
	"MA-15": true, "MA-16": true, "MA-AGD": true, "MA-AOU": true, "MA-ASZ": true,
	"MA-AZI": true, "MA-BEM": true, "MA-BER": true, "MA-BES": true, "MA-BOD": true,
	"MA-BOM": true, "MA-CAS": true, "MA-CHE": true, "MA-CHI": true, "MA-CHT": true,
	"MA-ERR": true, "MA-ESI": true, "MA-ESM": true, "MA-FAH": true, "MA-FES": true,
	"MA-FIG": true, "MA-GUE": true, "MA-HAJ": true, "MA-HAO": true, "MA-HOC": true,
	"MA-IFR": true, "MA-INE": true, "MA-JDI": true, "MA-JRA": true, "MA-KEN": true,
	"MA-KES": true, "MA-KHE": true, "MA-KHN": true, "MA-KHO": true, "MA-LAA": true,
	"MA-LAR": true, "MA-MED": true, "MA-MEK": true, "MA-MMD": true, "MA-MMN": true,
	"MA-MOH": true, "MA-MOU": true, "MA-NAD": true, "MA-NOU": true, "MA-OUA": true,
	"MA-OUD": true, "MA-OUJ": true, "MA-RAB": true, "MA-SAF": true, "MA-SAL": true,
	"MA-SEF": true, "MA-SET": true, "MA-SIK": true, "MA-SKH": true, "MA-SYB": true,
	"MA-TAI": true, "MA-TAO": true, "MA-TAR": true, "MA-TAT": true, "MA-TAZ": true,
	"MA-TET": true, "MA-TIZ": true, "MA-TNG": true, "MA-TNT": true, "MA-ZAG": true,
	"MC-CL": true, "MC-CO": true, "MC-FO": true, "MC-GA": true, "MC-JE": true,
	"MC-LA": true, "MC-MA": true, "MC-MC": true, "MC-MG": true, "MC-MO": true,
	"MC-MU": true, "MC-PH": true, "MC-SD": true, "MC-SO": true, "MC-SP": true,
	"MC-SR": true, "MC-VR": true, "MD-AN": true, "MD-BA": true, "MD-BD": true,
	"MD-BR": true, "MD-BS": true, "MD-CA": true, "MD-CL": true, "MD-CM": true,
	"MD-CR": true, "MD-CS": true, "MD-CT": true, "MD-CU": true, "MD-DO": true,
	"MD-DR": true, "MD-DU": true, "MD-ED": true, "MD-FA": true, "MD-FL": true,
	"MD-GA": true, "MD-GL": true, "MD-HI": true, "MD-IA": true, "MD-LE": true,
	"MD-NI": true, "MD-OC": true, "MD-OR": true, "MD-RE": true, "MD-RI": true,
	"MD-SD": true, "MD-SI": true, "MD-SN": true, "MD-SO": true, "MD-ST": true,
	"MD-SV": true, "MD-TA": true, "MD-TE": true, "MD-UN": true, "ME-01": true,
	"ME-02": true, "ME-03": true, "ME-04": true, "ME-05": true, "ME-06": true,
	"ME-07": true, "ME-08": true, "ME-09": true, "ME-10": true, "ME-11": true,
	"ME-12": true, "ME-13": true, "ME-14": true, "ME-15": true, "ME-16": true,
	"ME-17": true, "ME-18": true, "ME-19": true, "ME-20": true, "ME-21": true, "ME-24": true,
	"MG-A": true, "MG-D": true, "MG-F": true, "MG-M": true, "MG-T": true,
	"MG-U": true, "MH-ALK": true, "MH-ALL": true, "MH-ARN": true, "MH-AUR": true,
	"MH-EBO": true, "MH-ENI": true, "MH-JAB": true, "MH-JAL": true, "MH-KIL": true,
	"MH-KWA": true, "MH-L": true, "MH-LAE": true, "MH-LIB": true, "MH-LIK": true,
	"MH-MAJ": true, "MH-MAL": true, "MH-MEJ": true, "MH-MIL": true, "MH-NMK": true,
	"MH-NMU": true, "MH-RON": true, "MH-T": true, "MH-UJA": true, "MH-UTI": true,
	"MH-WTJ": true, "MH-WTN": true, "MK-101": true, "MK-102": true, "MK-103": true,
	"MK-104": true, "MK-105": true,
	"MK-106": true, "MK-107": true, "MK-108": true, "MK-109": true, "MK-201": true,
	"MK-202": true, "MK-205": true, "MK-206": true, "MK-207": true, "MK-208": true,
	"MK-209": true, "MK-210": true, "MK-211": true, "MK-301": true, "MK-303": true,
	"MK-307": true, "MK-308": true, "MK-310": true, "MK-311": true, "MK-312": true,
	"MK-401": true, "MK-402": true, "MK-403": true, "MK-404": true, "MK-405": true,
	"MK-406": true, "MK-408": true, "MK-409": true, "MK-410": true, "MK-501": true,
	"MK-502": true, "MK-503": true, "MK-505": true, "MK-506": true, "MK-507": true,
	"MK-508": true, "MK-509": true, "MK-601": true, "MK-602": true, "MK-604": true,
	"MK-605": true, "MK-606": true, "MK-607": true, "MK-608": true, "MK-609": true,
	"MK-701": true, "MK-702": true, "MK-703": true, "MK-704": true, "MK-705": true,
	"MK-803": true, "MK-804": true, "MK-806": true, "MK-807": true, "MK-809": true,
	"MK-810": true, "MK-811": true, "MK-812": true, "MK-813": true, "MK-814": true,
	"MK-816": true, "ML-1": true, "ML-2": true, "ML-3": true, "ML-4": true,
	"ML-5": true, "ML-6": true, "ML-7": true, "ML-8": true, "ML-BKO": true,
	"MM-01": true, "MM-02": true, "MM-03": true, "MM-04": true, "MM-05": true,
	"MM-06": true, "MM-07": true, "MM-11": true, "MM-12": true, "MM-13": true,
	"MM-14": true, "MM-15": true, "MM-16": true, "MM-17": true, "MM-18": true, "MN-035": true,
	"MN-037": true, "MN-039": true, "MN-041": true, "MN-043": true, "MN-046": true,
	"MN-047": true, "MN-049": true, "MN-051": true, "MN-053": true, "MN-055": true,
	"MN-057": true, "MN-059": true, "MN-061": true, "MN-063": true, "MN-064": true,
	"MN-065": true, "MN-067": true, "MN-069": true, "MN-071": true, "MN-073": true,
	"MN-1": true, "MR-01": true, "MR-02": true, "MR-03": true, "MR-04": true,
	"MR-05": true, "MR-06": true, "MR-07": true, "MR-08": true, "MR-09": true,
	"MR-10": true, "MR-11": true, "MR-12": true, "MR-13": true, "MR-NKC": true, "MT-01": true,
	"MT-02": true, "MT-03": true, "MT-04": true, "MT-05": true, "MT-06": true,
	"MT-07": true, "MT-08": true, "MT-09": true, "MT-10": true, "MT-11": true,
	"MT-12": true, "MT-13": true, "MT-14": true, "MT-15": true, "MT-16": true,
	"MT-17": true, "MT-18": true, "MT-19": true, "MT-20": true, "MT-21": true,
	"MT-22": true, "MT-23": true, "MT-24": true, "MT-25": true, "MT-26": true,
	"MT-27": true, "MT-28": true, "MT-29": true, "MT-30": true, "MT-31": true,
	"MT-32": true, "MT-33": true, "MT-34": true, "MT-35": true, "MT-36": true,
	"MT-37": true, "MT-38": true, "MT-39": true, "MT-40": true, "MT-41": true,
	"MT-42": true, "MT-43": true, "MT-44": true, "MT-45": true, "MT-46": true,
	"MT-47": true, "MT-48": true, "MT-49": true, "MT-50": true, "MT-51": true,
	"MT-52": true, "MT-53": true, "MT-54": true, "MT-55": true, "MT-56": true,
	"MT-57": true, "MT-58": true, "MT-59": true, "MT-60": true, "MT-61": true,
	"MT-62": true, "MT-63": true, "MT-64": true, "MT-65": true, "MT-66": true,
	"MT-67": true, "MT-68": true, "MU-AG": true, "MU-BL": true, "MU-BR": true,
	"MU-CC": true, "MU-CU": true, "MU-FL": true, "MU-GP": true, "MU-MO": true,
	"MU-PA": true, "MU-PL": true, "MU-PU": true, "MU-PW": true, "MU-QB": true,
	"MU-RO": true, "MU-RP": true, "MU-RR": true, "MU-SA": true, "MU-VP": true, "MV-00": true,
	"MV-01": true, "MV-02": true, "MV-03": true, "MV-04": true, "MV-05": true,
	"MV-07": true, "MV-08": true, "MV-12": true, "MV-13": true, "MV-14": true,
	"MV-17": true, "MV-20": true, "MV-23": true, "MV-24": true, "MV-25": true,
	"MV-26": true, "MV-27": true, "MV-28": true, "MV-29": true, "MV-CE": true,
	"MV-MLE": true, "MV-NC": true, "MV-NO": true, "MV-SC": true, "MV-SU": true,
	"MV-UN": true, "MV-US": true, "MW-BA": true, "MW-BL": true, "MW-C": true,
	"MW-CK": true, "MW-CR": true, "MW-CT": true, "MW-DE": true, "MW-DO": true,
	"MW-KR": true, "MW-KS": true, "MW-LI": true, "MW-LK": true, "MW-MC": true,
	"MW-MG": true, "MW-MH": true, "MW-MU": true, "MW-MW": true, "MW-MZ": true,
	"MW-N": true, "MW-NB": true, "MW-NE": true, "MW-NI": true, "MW-NK": true,
	"MW-NS": true, "MW-NU": true, "MW-PH": true, "MW-RU": true, "MW-S": true,
	"MW-SA": true, "MW-TH": true, "MW-ZO": true, "MX-AGU": true, "MX-BCN": true,
	"MX-BCS": true, "MX-CAM": true, "MX-CHH": true, "MX-CHP": true, "MX-COA": true,
	"MX-COL": true, "MX-CMX": true, "MX-DIF": true, "MX-DUR": true, "MX-GRO": true, "MX-GUA": true,
	"MX-HID": true, "MX-JAL": true, "MX-MEX": true, "MX-MIC": true, "MX-MOR": true,
	"MX-NAY": true, "MX-NLE": true, "MX-OAX": true, "MX-PUE": true, "MX-QUE": true,
	"MX-ROO": true, "MX-SIN": true, "MX-SLP": true, "MX-SON": true, "MX-TAB": true,
	"MX-TAM": true, "MX-TLA": true, "MX-VER": true, "MX-YUC": true, "MX-ZAC": true,
	"MY-01": true, "MY-02": true, "MY-03": true, "MY-04": true, "MY-05": true,
	"MY-06": true, "MY-07": true, "MY-08": true, "MY-09": true, "MY-10": true,
	"MY-11": true, "MY-12": true, "MY-13": true, "MY-14": true, "MY-15": true,
	"MY-16": true, "MZ-A": true, "MZ-B": true, "MZ-G": true, "MZ-I": true,
	"MZ-L": true, "MZ-MPM": true, "MZ-N": true, "MZ-P": true, "MZ-Q": true,
	"MZ-S": true, "MZ-T": true, "NA-CA": true, "NA-ER": true, "NA-HA": true,
	"NA-KA": true, "NA-KE": true, "NA-KH": true, "NA-KU": true, "NA-KW": true, "NA-OD": true, "NA-OH": true,
	"NA-OK": true, "NA-ON": true, "NA-OS": true, "NA-OT": true, "NA-OW": true,
	"NE-1": true, "NE-2": true, "NE-3": true, "NE-4": true, "NE-5": true,
	"NE-6": true, "NE-7": true, "NE-8": true, "NG-AB": true, "NG-AD": true,
	"NG-AK": true, "NG-AN": true, "NG-BA": true, "NG-BE": true, "NG-BO": true,
	"NG-BY": true, "NG-CR": true, "NG-DE": true, "NG-EB": true, "NG-ED": true,
	"NG-EK": true, "NG-EN": true, "NG-FC": true, "NG-GO": true, "NG-IM": true,
	"NG-JI": true, "NG-KD": true, "NG-KE": true, "NG-KN": true, "NG-KO": true,
	"NG-KT": true, "NG-KW": true, "NG-LA": true, "NG-NA": true, "NG-NI": true,
	"NG-OG": true, "NG-ON": true, "NG-OS": true, "NG-OY": true, "NG-PL": true,
	"NG-RI": true, "NG-SO": true, "NG-TA": true, "NG-YO": true, "NG-ZA": true,
	"NI-AN": true, "NI-AS": true, "NI-BO": true, "NI-CA": true, "NI-CI": true,
	"NI-CO": true, "NI-ES": true, "NI-GR": true, "NI-JI": true, "NI-LE": true,
	"NI-MD": true, "NI-MN": true, "NI-MS": true, "NI-MT": true, "NI-NS": true,
	"NI-RI": true, "NI-SJ": true, "NL-AW": true, "NL-BQ1": true, "NL-BQ2": true,
	"NL-BQ3": true, "NL-CW": true, "NL-DR": true, "NL-FL": true, "NL-FR": true,
	"NL-GE": true, "NL-GR": true, "NL-LI": true, "NL-NB": true, "NL-NH": true,
	"NL-OV": true, "NL-SX": true, "NL-UT": true, "NL-ZE": true, "NL-ZH": true,
	"NO-03": true, "NO-11": true, "NO-15": true, "NO-16": true, "NO-17": true,
	"NO-18": true, "NO-21": true, "NO-30": true, "NO-34": true, "NO-38": true,
	"NO-42": true, "NO-46": true, "NO-50": true, "NO-54": true,
	"NO-22": true, "NP-1": true, "NP-2": true, "NP-3": true, "NP-4": true,
	"NP-5": true, "NP-BA": true, "NP-BH": true, "NP-DH": true, "NP-GA": true,
	"NP-JA": true, "NP-KA": true, "NP-KO": true, "NP-LU": true, "NP-MA": true,
	"NP-ME": true, "NP-NA": true, "NP-RA": true, "NP-SA": true, "NP-SE": true,
	"NR-01": true, "NR-02": true, "NR-03": true, "NR-04": true, "NR-05": true,
	"NR-06": true, "NR-07": true, "NR-08": true, "NR-09": true, "NR-10": true,
	"NR-11": true, "NR-12": true, "NR-13": true, "NR-14": true, "NZ-AUK": true,
	"NZ-BOP": true, "NZ-CAN": true, "NZ-CIT": true, "NZ-GIS": true, "NZ-HKB": true,
	"NZ-MBH": true, "NZ-MWT": true, "NZ-N": true, "NZ-NSN": true, "NZ-NTL": true,
	"NZ-OTA": true, "NZ-S": true, "NZ-STL": true, "NZ-TAS": true, "NZ-TKI": true,
	"NZ-WGN": true, "NZ-WKO": true, "NZ-WTC": true, "OM-BA": true, "OM-BS": true, "OM-BU": true, "OM-BJ": true,
	"OM-DA": true, "OM-MA": true, "OM-MU": true, "OM-SH": true, "OM-SJ": true, "OM-SS": true, "OM-WU": true,
	"OM-ZA": true, "OM-ZU": true, "PA-1": true, "PA-2": true, "PA-3": true,
	"PA-4": true, "PA-5": true, "PA-6": true, "PA-7": true, "PA-8": true,
	"PA-9": true, "PA-EM": true, "PA-KY": true, "PA-NB": true, "PE-AMA": true,
	"PE-ANC": true, "PE-APU": true, "PE-ARE": true, "PE-AYA": true, "PE-CAJ": true,
	"PE-CAL": true, "PE-CUS": true, "PE-HUC": true, "PE-HUV": true, "PE-ICA": true,
	"PE-JUN": true, "PE-LAL": true, "PE-LAM": true, "PE-LIM": true, "PE-LMA": true,
	"PE-LOR": true, "PE-MDD": true, "PE-MOQ": true, "PE-PAS": true, "PE-PIU": true,
	"PE-PUN": true, "PE-SAM": true, "PE-TAC": true, "PE-TUM": true, "PE-UCA": true,
	"PG-CPK": true, "PG-CPM": true, "PG-EBR": true, "PG-EHG": true, "PG-EPW": true,
	"PG-ESW": true, "PG-GPK": true, "PG-MBA": true, "PG-MPL": true, "PG-MPM": true,
	"PG-MRL": true, "PG-NCD": true, "PG-NIK": true, "PG-NPP": true, "PG-NSB": true,
	"PG-SAN": true, "PG-SHM": true, "PG-WBK": true, "PG-WHM": true, "PG-WPD": true,
	"PH-00": true, "PH-01": true, "PH-02": true, "PH-03": true, "PH-05": true,
	"PH-06": true, "PH-07": true, "PH-08": true, "PH-09": true, "PH-10": true,
	"PH-11": true, "PH-12": true, "PH-13": true, "PH-14": true, "PH-15": true,
	"PH-40": true, "PH-41": true, "PH-ABR": true, "PH-AGN": true, "PH-AGS": true,
	"PH-AKL": true, "PH-ALB": true, "PH-ANT": true, "PH-APA": true, "PH-AUR": true,
	"PH-BAN": true, "PH-BAS": true, "PH-BEN": true, "PH-BIL": true, "PH-BOH": true,
	"PH-BTG": true, "PH-BTN": true, "PH-BUK": true, "PH-BUL": true, "PH-CAG": true,
	"PH-CAM": true, "PH-CAN": true, "PH-CAP": true, "PH-CAS": true, "PH-CAT": true,
	"PH-CAV": true, "PH-CEB": true, "PH-COM": true, "PH-DAO": true, "PH-DAS": true,
	"PH-DAV": true, "PH-DIN": true, "PH-EAS": true, "PH-GUI": true, "PH-IFU": true,
	"PH-ILI": true, "PH-ILN": true, "PH-ILS": true, "PH-ISA": true, "PH-KAL": true,
	"PH-LAG": true, "PH-LAN": true, "PH-LAS": true, "PH-LEY": true, "PH-LUN": true,
	"PH-MAD": true, "PH-MAG": true, "PH-MAS": true, "PH-MDC": true, "PH-MDR": true,
	"PH-MOU": true, "PH-MSC": true, "PH-MSR": true, "PH-NCO": true, "PH-NEC": true,
	"PH-NER": true, "PH-NSA": true, "PH-NUE": true, "PH-NUV": true, "PH-PAM": true,
	"PH-PAN": true, "PH-PLW": true, "PH-QUE": true, "PH-QUI": true, "PH-RIZ": true,
	"PH-ROM": true, "PH-SAR": true, "PH-SCO": true, "PH-SIG": true, "PH-SLE": true,
	"PH-SLU": true, "PH-SOR": true, "PH-SUK": true, "PH-SUN": true, "PH-SUR": true,
	"PH-TAR": true, "PH-TAW": true, "PH-WSA": true, "PH-ZAN": true, "PH-ZAS": true,
	"PH-ZMB": true, "PH-ZSI": true, "PK-BA": true, "PK-GB": true, "PK-IS": true,
	"PK-JK": true, "PK-KP": true, "PK-PB": true, "PK-SD": true, "PK-TA": true,
	"PL-02": true, "PL-04": true, "PL-06": true, "PL-08": true, "PL-10": true,
	"PL-12": true, "PL-14": true, "PL-16": true, "PL-18": true, "PL-20": true,
	"PL-22": true, "PL-24": true, "PL-26": true, "PL-28": true, "PL-30": true, "PL-32": true,
	"PS-BTH": true, "PS-DEB": true, "PS-GZA": true, "PS-HBN": true,
	"PS-JEM": true, "PS-JEN": true, "PS-JRH": true, "PS-KYS": true, "PS-NBS": true,
	"PS-NGZ": true, "PS-QQA": true, "PS-RBH": true, "PS-RFH": true, "PS-SLT": true,
	"PS-TBS": true, "PS-TKM": true, "PT-01": true, "PT-02": true, "PT-03": true,
	"PT-04": true, "PT-05": true, "PT-06": true, "PT-07": true, "PT-08": true,
	"PT-09": true, "PT-10": true, "PT-11": true, "PT-12": true, "PT-13": true,
	"PT-14": true, "PT-15": true, "PT-16": true, "PT-17": true, "PT-18": true,
	"PT-20": true, "PT-30": true, "PW-002": true, "PW-004": true, "PW-010": true,
	"PW-050": true, "PW-100": true, "PW-150": true, "PW-212": true, "PW-214": true,
	"PW-218": true, "PW-222": true, "PW-224": true, "PW-226": true, "PW-227": true,
	"PW-228": true, "PW-350": true, "PW-370": true, "PY-1": true, "PY-10": true,
	"PY-11": true, "PY-12": true, "PY-13": true, "PY-14": true, "PY-15": true,
	"PY-16": true, "PY-19": true, "PY-2": true, "PY-3": true, "PY-4": true,
	"PY-5": true, "PY-6": true, "PY-7": true, "PY-8": true, "PY-9": true,
	"PY-ASU": true, "QA-DA": true, "QA-KH": true, "QA-MS": true, "QA-RA": true,
	"QA-US": true, "QA-WA": true, "QA-ZA": true, "RO-AB": true, "RO-AG": true,
	"RO-AR": true, "RO-B": true, "RO-BC": true, "RO-BH": true, "RO-BN": true,
	"RO-BR": true, "RO-BT": true, "RO-BV": true, "RO-BZ": true, "RO-CJ": true,
	"RO-CL": true, "RO-CS": true, "RO-CT": true, "RO-CV": true, "RO-DB": true,
	"RO-DJ": true, "RO-GJ": true, "RO-GL": true, "RO-GR": true, "RO-HD": true,
	"RO-HR": true, "RO-IF": true, "RO-IL": true, "RO-IS": true, "RO-MH": true,
	"RO-MM": true, "RO-MS": true, "RO-NT": true, "RO-OT": true, "RO-PH": true,
	"RO-SB": true, "RO-SJ": true, "RO-SM": true, "RO-SV": true, "RO-TL": true,
	"RO-TM": true, "RO-TR": true, "RO-VL": true, "RO-VN": true, "RO-VS": true,
	"RS-00": true, "RS-01": true, "RS-02": true, "RS-03": true, "RS-04": true,
	"RS-05": true, "RS-06": true, "RS-07": true, "RS-08": true, "RS-09": true,
	"RS-10": true, "RS-11": true, "RS-12": true, "RS-13": true, "RS-14": true,
	"RS-15": true, "RS-16": true, "RS-17": true, "RS-18": true, "RS-19": true,
	"RS-20": true, "RS-21": true, "RS-22": true, "RS-23": true, "RS-24": true,
	"RS-25": true, "RS-26": true, "RS-27": true, "RS-28": true, "RS-29": true,
	"RS-KM": true, "RS-VO": true, "RU-AD": true, "RU-AL": true, "RU-ALT": true,
	"RU-AMU": true, "RU-ARK": true, "RU-AST": true, "RU-BA": true, "RU-BEL": true,
	"RU-BRY": true, "RU-BU": true, "RU-CE": true, "RU-CHE": true, "RU-CHU": true,
	"RU-CU": true, "RU-DA": true, "RU-IN": true, "RU-IRK": true, "RU-IVA": true,
	"RU-KAM": true, "RU-KB": true, "RU-KC": true, "RU-KDA": true, "RU-KEM": true,
	"RU-KGD": true, "RU-KGN": true, "RU-KHA": true, "RU-KHM": true, "RU-KIR": true,
	"RU-KK": true, "RU-KL": true, "RU-KLU": true, "RU-KO": true, "RU-KOS": true,
	"RU-KR": true, "RU-KRS": true, "RU-KYA": true, "RU-LEN": true, "RU-LIP": true,
	"RU-MAG": true, "RU-ME": true, "RU-MO": true, "RU-MOS": true, "RU-MOW": true,
	"RU-MUR": true, "RU-NEN": true, "RU-NGR": true, "RU-NIZ": true, "RU-NVS": true,
	"RU-OMS": true, "RU-ORE": true, "RU-ORL": true, "RU-PER": true, "RU-PNZ": true,
	"RU-PRI": true, "RU-PSK": true, "RU-ROS": true, "RU-RYA": true, "RU-SA": true,
	"RU-SAK": true, "RU-SAM": true, "RU-SAR": true, "RU-SE": true, "RU-SMO": true,
	"RU-SPE": true, "RU-STA": true, "RU-SVE": true, "RU-TA": true, "RU-TAM": true,
	"RU-TOM": true, "RU-TUL": true, "RU-TVE": true, "RU-TY": true, "RU-TYU": true,
	"RU-UD": true, "RU-ULY": true, "RU-VGG": true, "RU-VLA": true, "RU-VLG": true,
	"RU-VOR": true, "RU-YAN": true, "RU-YAR": true, "RU-YEV": true, "RU-ZAB": true,
	"RW-01": true, "RW-02": true, "RW-03": true, "RW-04": true, "RW-05": true,
	"SA-01": true, "SA-02": true, "SA-03": true, "SA-04": true, "SA-05": true,
	"SA-06": true, "SA-07": true, "SA-08": true, "SA-09": true, "SA-10": true,
	"SA-11": true, "SA-12": true, "SA-14": true, "SB-CE": true, "SB-CH": true,
	"SB-CT": true, "SB-GU": true, "SB-IS": true, "SB-MK": true, "SB-ML": true,
	"SB-RB": true, "SB-TE": true, "SB-WE": true, "SC-01": true, "SC-02": true,
	"SC-03": true, "SC-04": true, "SC-05": true, "SC-06": true, "SC-07": true,
	"SC-08": true, "SC-09": true, "SC-10": true, "SC-11": true, "SC-12": true,
	"SC-13": true, "SC-14": true, "SC-15": true, "SC-16": true, "SC-17": true,
	"SC-18": true, "SC-19": true, "SC-20": true, "SC-21": true, "SC-22": true,
	"SC-23": true, "SC-24": true, "SC-25": true, "SD-DC": true, "SD-DE": true,
	"SD-DN": true, "SD-DS": true, "SD-DW": true, "SD-GD": true, "SD-GK": true, "SD-GZ": true,
	"SD-KA": true, "SD-KH": true, "SD-KN": true, "SD-KS": true, "SD-NB": true,
	"SD-NO": true, "SD-NR": true, "SD-NW": true, "SD-RS": true, "SD-SI": true,
	"SE-AB": true, "SE-AC": true, "SE-BD": true, "SE-C": true, "SE-D": true,
	"SE-E": true, "SE-F": true, "SE-G": true, "SE-H": true, "SE-I": true,
	"SE-K": true, "SE-M": true, "SE-N": true, "SE-O": true, "SE-S": true,
	"SE-T": true, "SE-U": true, "SE-W": true, "SE-X": true, "SE-Y": true,
	"SE-Z": true, "SG-01": true, "SG-02": true, "SG-03": true, "SG-04": true,
	"SG-05": true, "SH-AC": true, "SH-HL": true, "SH-TA": true, "SI-001": true,
	"SI-002": true, "SI-003": true, "SI-004": true, "SI-005": true, "SI-006": true,
	"SI-007": true, "SI-008": true, "SI-009": true, "SI-010": true, "SI-011": true,
	"SI-012": true, "SI-013": true, "SI-014": true, "SI-015": true, "SI-016": true,
	"SI-017": true, "SI-018": true, "SI-019": true, "SI-020": true, "SI-021": true,
	"SI-022": true, "SI-023": true, "SI-024": true, "SI-025": true, "SI-026": true,
	"SI-027": true, "SI-028": true, "SI-029": true, "SI-030": true, "SI-031": true,
	"SI-032": true, "SI-033": true, "SI-034": true, "SI-035": true, "SI-036": true,
	"SI-037": true, "SI-038": true, "SI-039": true, "SI-040": true, "SI-041": true,
	"SI-042": true, "SI-043": true, "SI-044": true, "SI-045": true, "SI-046": true,
	"SI-047": true, "SI-048": true, "SI-049": true, "SI-050": true, "SI-051": true,
	"SI-052": true, "SI-053": true, "SI-054": true, "SI-055": true, "SI-056": true,
	"SI-057": true, "SI-058": true, "SI-059": true, "SI-060": true, "SI-061": true,
	"SI-062": true, "SI-063": true, "SI-064": true, "SI-065": true, "SI-066": true,
	"SI-067": true, "SI-068": true, "SI-069": true, "SI-070": true, "SI-071": true,
	"SI-072": true, "SI-073": true, "SI-074": true, "SI-075": true, "SI-076": true,
	"SI-077": true, "SI-078": true, "SI-079": true, "SI-080": true, "SI-081": true,
	"SI-082": true, "SI-083": true, "SI-084": true, "SI-085": true, "SI-086": true,
	"SI-087": true, "SI-088": true, "SI-089": true, "SI-090": true, "SI-091": true,
	"SI-092": true, "SI-093": true, "SI-094": true, "SI-095": true, "SI-096": true,
	"SI-097": true, "SI-098": true, "SI-099": true, "SI-100": true, "SI-101": true,
	"SI-102": true, "SI-103": true, "SI-104": true, "SI-105": true, "SI-106": true,
	"SI-107": true, "SI-108": true, "SI-109": true, "SI-110": true, "SI-111": true,
	"SI-112": true, "SI-113": true, "SI-114": true, "SI-115": true, "SI-116": true,
	"SI-117": true, "SI-118": true, "SI-119": true, "SI-120": true, "SI-121": true,
	"SI-122": true, "SI-123": true, "SI-124": true, "SI-125": true, "SI-126": true,
	"SI-127": true, "SI-128": true, "SI-129": true, "SI-130": true, "SI-131": true,
	"SI-132": true, "SI-133": true, "SI-134": true, "SI-135": true, "SI-136": true,
	"SI-137": true, "SI-138": true, "SI-139": true, "SI-140": true, "SI-141": true,
	"SI-142": true, "SI-143": true, "SI-144": true, "SI-146": true, "SI-147": true,
	"SI-148": true, "SI-149": true, "SI-150": true, "SI-151": true, "SI-152": true,
	"SI-153": true, "SI-154": true, "SI-155": true, "SI-156": true, "SI-157": true,
	"SI-158": true, "SI-159": true, "SI-160": true, "SI-161": true, "SI-162": true,
	"SI-163": true, "SI-164": true, "SI-165": true, "SI-166": true, "SI-167": true,
	"SI-168": true, "SI-169": true, "SI-170": true, "SI-171": true, "SI-172": true,
	"SI-173": true, "SI-174": true, "SI-175": true, "SI-176": true, "SI-177": true,
	"SI-178": true, "SI-179": true, "SI-180": true, "SI-181": true, "SI-182": true,
	"SI-183": true, "SI-184": true, "SI-185": true, "SI-186": true, "SI-187": true,
	"SI-188": true, "SI-189": true, "SI-190": true, "SI-191": true, "SI-192": true,
	"SI-193": true, "SI-194": true, "SI-195": true, "SI-196": true, "SI-197": true,
	"SI-198": true, "SI-199": true, "SI-200": true, "SI-201": true, "SI-202": true,
	"SI-203": true, "SI-204": true, "SI-205": true, "SI-206": true, "SI-207": true,
	"SI-208": true, "SI-209": true, "SI-210": true, "SI-211": true, "SI-212": true, "SI-213": true, "SK-BC": true,
	"SK-BL": true, "SK-KI": true, "SK-NI": true, "SK-PV": true, "SK-TA": true,
	"SK-TC": true, "SK-ZI": true, "SL-E": true, "SL-N": true, "SL-S": true,
	"SL-W": true, "SM-01": true, "SM-02": true, "SM-03": true, "SM-04": true,
	"SM-05": true, "SM-06": true, "SM-07": true, "SM-08": true, "SM-09": true,
	"SN-DB": true, "SN-DK": true, "SN-FK": true, "SN-KA": true, "SN-KD": true,
	"SN-KE": true, "SN-KL": true, "SN-LG": true, "SN-MT": true, "SN-SE": true,
	"SN-SL": true, "SN-TC": true, "SN-TH": true, "SN-ZG": true, "SO-AW": true,
	"SO-BK": true, "SO-BN": true, "SO-BR": true, "SO-BY": true, "SO-GA": true,
	"SO-GE": true, "SO-HI": true, "SO-JD": true, "SO-JH": true, "SO-MU": true,
	"SO-NU": true, "SO-SA": true, "SO-SD": true, "SO-SH": true, "SO-SO": true,
	"SO-TO": true, "SO-WO": true, "SR-BR": true, "SR-CM": true, "SR-CR": true,
	"SR-MA": true, "SR-NI": true, "SR-PM": true, "SR-PR": true, "SR-SA": true,
	"SR-SI": true, "SR-WA": true, "SS-BN": true, "SS-BW": true, "SS-EC": true,
	"SS-EE8": true, "SS-EE": true, "SS-EW": true, "SS-JG": true, "SS-LK": true, "SS-NU": true,
	"SS-UY": true, "SS-WR": true, "ST-01": true, "ST-P": true, "ST-S": true, "SV-AH": true,
	"SV-CA": true, "SV-CH": true, "SV-CU": true, "SV-LI": true, "SV-MO": true,
	"SV-PA": true, "SV-SA": true, "SV-SM": true, "SV-SO": true, "SV-SS": true,
	"SV-SV": true, "SV-UN": true, "SV-US": true, "SY-DI": true, "SY-DR": true,
	"SY-DY": true, "SY-HA": true, "SY-HI": true, "SY-HL": true, "SY-HM": true,
	"SY-ID": true, "SY-LA": true, "SY-QU": true, "SY-RA": true, "SY-RD": true,
	"SY-SU": true, "SY-TA": true, "SZ-HH": true, "SZ-LU": true, "SZ-MA": true,
	"SZ-SH": true, "TD-BA": true, "TD-BG": true, "TD-BO": true, "TD-CB": true,
	"TD-EN": true, "TD-GR": true, "TD-HL": true, "TD-KA": true, "TD-LC": true,
	"TD-LO": true, "TD-LR": true, "TD-MA": true, "TD-MC": true, "TD-ME": true,
	"TD-MO": true, "TD-ND": true, "TD-OD": true, "TD-SA": true, "TD-SI": true,
	"TD-TA": true, "TD-TI": true, "TD-WF": true, "TG-C": true, "TG-K": true,
	"TG-M": true, "TG-P": true, "TG-S": true, "TH-10": true, "TH-11": true,
	"TH-12": true, "TH-13": true, "TH-14": true, "TH-15": true, "TH-16": true,
	"TH-17": true, "TH-18": true, "TH-19": true, "TH-20": true, "TH-21": true,
	"TH-22": true, "TH-23": true, "TH-24": true, "TH-25": true, "TH-26": true,
	"TH-27": true, "TH-30": true, "TH-31": true, "TH-32": true, "TH-33": true,
	"TH-34": true, "TH-35": true, "TH-36": true, "TH-37": true, "TH-38": true, "TH-39": true,
	"TH-40": true, "TH-41": true, "TH-42": true, "TH-43": true, "TH-44": true,
	"TH-45": true, "TH-46": true, "TH-47": true, "TH-48": true, "TH-49": true,
	"TH-50": true, "TH-51": true, "TH-52": true, "TH-53": true, "TH-54": true,
	"TH-55": true, "TH-56": true, "TH-57": true, "TH-58": true, "TH-60": true,
	"TH-61": true, "TH-62": true, "TH-63": true, "TH-64": true, "TH-65": true,
	"TH-66": true, "TH-67": true, "TH-70": true, "TH-71": true, "TH-72": true,
	"TH-73": true, "TH-74": true, "TH-75": true, "TH-76": true, "TH-77": true,
	"TH-80": true, "TH-81": true, "TH-82": true, "TH-83": true, "TH-84": true,
	"TH-85": true, "TH-86": true, "TH-90": true, "TH-91": true, "TH-92": true,
	"TH-93": true, "TH-94": true, "TH-95": true, "TH-96": true, "TH-S": true,
	"TJ-GB": true, "TJ-KT": true, "TJ-SU": true, "TJ-DU": true, "TJ-RA": true, "TL-AL": true, "TL-AN": true,
	"TL-BA": true, "TL-BO": true, "TL-CO": true, "TL-DI": true, "TL-ER": true,
	"TL-LA": true, "TL-LI": true, "TL-MF": true, "TL-MT": true, "TL-OE": true,
	"TL-VI": true, "TM-A": true, "TM-B": true, "TM-D": true, "TM-L": true,
	"TM-M": true, "TM-S": true, "TN-11": true, "TN-12": true, "TN-13": true,
	"TN-14": true, "TN-21": true, "TN-22": true, "TN-23": true, "TN-31": true,
	"TN-32": true, "TN-33": true, "TN-34": true, "TN-41": true, "TN-42": true,
	"TN-43": true, "TN-51": true, "TN-52": true, "TN-53": true, "TN-61": true,
	"TN-71": true, "TN-72": true, "TN-73": true, "TN-81": true, "TN-82": true,
	"TN-83": true, "TO-01": true, "TO-02": true, "TO-03": true, "TO-04": true,
	"TO-05": true, "TR-01": true, "TR-02": true, "TR-03": true, "TR-04": true,
	"TR-05": true, "TR-06": true, "TR-07": true, "TR-08": true, "TR-09": true,
	"TR-10": true, "TR-11": true, "TR-12": true, "TR-13": true, "TR-14": true,
	"TR-15": true, "TR-16": true, "TR-17": true, "TR-18": true, "TR-19": true,
	"TR-20": true, "TR-21": true, "TR-22": true, "TR-23": true, "TR-24": true,
	"TR-25": true, "TR-26": true, "TR-27": true, "TR-28": true, "TR-29": true,
	"TR-30": true, "TR-31": true, "TR-32": true, "TR-33": true, "TR-34": true,
	"TR-35": true, "TR-36": true, "TR-37": true, "TR-38": true, "TR-39": true,
	"TR-40": true, "TR-41": true, "TR-42": true, "TR-43": true, "TR-44": true,
	"TR-45": true, "TR-46": true, "TR-47": true, "TR-48": true, "TR-49": true,
	"TR-50": true, "TR-51": true, "TR-52": true, "TR-53": true, "TR-54": true,
	"TR-55": true, "TR-56": true, "TR-57": true, "TR-58": true, "TR-59": true,
	"TR-60": true, "TR-61": true, "TR-62": true, "TR-63": true, "TR-64": true,
	"TR-65": true, "TR-66": true, "TR-67": true, "TR-68": true, "TR-69": true,
	"TR-70": true, "TR-71": true, "TR-72": true, "TR-73": true, "TR-74": true,
	"TR-75": true, "TR-76": true, "TR-77": true, "TR-78": true, "TR-79": true,
	"TR-80": true, "TR-81": true, "TT-ARI": true, "TT-CHA": true, "TT-CTT": true,
	"TT-DMN": true, "TT-ETO": true, "TT-MRC": true, "TT-TOB": true, "TT-PED": true, "TT-POS": true, "TT-PRT": true,
	"TT-PTF": true, "TT-RCM": true, "TT-SFO": true, "TT-SGE": true, "TT-SIP": true,
	"TT-SJL": true, "TT-TUP": true, "TT-WTO": true, "TV-FUN": true, "TV-NIT": true,
	"TV-NKF": true, "TV-NKL": true, "TV-NMA": true, "TV-NMG": true, "TV-NUI": true,
	"TV-VAI": true, "TW-CHA": true, "TW-CYI": true, "TW-CYQ": true, "TW-KIN": true, "TW-HSQ": true,
	"TW-HSZ": true, "TW-HUA": true, "TW-LIE": true, "TW-ILA": true, "TW-KEE": true, "TW-KHH": true,
	"TW-KHQ": true, "TW-MIA": true, "TW-NAN": true, "TW-NWT": true, "TW-PEN": true, "TW-PIF": true,
	"TW-TAO": true, "TW-TNN": true, "TW-TNQ": true, "TW-TPE": true, "TW-TPQ": true,
	"TW-TTT": true, "TW-TXG": true, "TW-TXQ": true, "TW-YUN": true, "TZ-01": true,
	"TZ-02": true, "TZ-03": true, "TZ-04": true, "TZ-05": true, "TZ-06": true,
	"TZ-07": true, "TZ-08": true, "TZ-09": true, "TZ-10": true, "TZ-11": true,
	"TZ-12": true, "TZ-13": true, "TZ-14": true, "TZ-15": true, "TZ-16": true,
	"TZ-17": true, "TZ-18": true, "TZ-19": true, "TZ-20": true, "TZ-21": true,
	"TZ-22": true, "TZ-23": true, "TZ-24": true, "TZ-25": true, "TZ-26": true, "TZ-27": true, "TZ-28": true, "TZ-29": true, "TZ-30": true, "TZ-31": true,
	"UA-05": true, "UA-07": true, "UA-09": true, "UA-12": true, "UA-14": true,
	"UA-18": true, "UA-21": true, "UA-23": true, "UA-26": true, "UA-30": true,
	"UA-32": true, "UA-35": true, "UA-40": true, "UA-43": true, "UA-46": true,
	"UA-48": true, "UA-51": true, "UA-53": true, "UA-56": true, "UA-59": true,
	"UA-61": true, "UA-63": true, "UA-65": true, "UA-68": true, "UA-71": true,
	"UA-74": true, "UA-77": true, "UG-101": true, "UG-102": true, "UG-103": true,
	"UG-104": true, "UG-105": true, "UG-106": true, "UG-107": true, "UG-108": true,
	"UG-109": true, "UG-110": true, "UG-111": true, "UG-112": true, "UG-113": true,
	"UG-114": true, "UG-115": true, "UG-116": true, "UG-201": true, "UG-202": true,
	"UG-203": true, "UG-204": true, "UG-205": true, "UG-206": true, "UG-207": true,
	"UG-208": true, "UG-209": true, "UG-210": true, "UG-211": true, "UG-212": true,
	"UG-213": true, "UG-214": true, "UG-215": true, "UG-216": true, "UG-217": true,
	"UG-218": true, "UG-219": true, "UG-220": true, "UG-221": true, "UG-222": true,
	"UG-223": true, "UG-224": true, "UG-301": true, "UG-302": true, "UG-303": true,
	"UG-304": true, "UG-305": true, "UG-306": true, "UG-307": true, "UG-308": true,
	"UG-309": true, "UG-310": true, "UG-311": true, "UG-312": true, "UG-313": true,
	"UG-314": true, "UG-315": true, "UG-316": true, "UG-317": true, "UG-318": true,
	"UG-319": true, "UG-320": true, "UG-321": true, "UG-401": true, "UG-402": true,
	"UG-403": true, "UG-404": true, "UG-405": true, "UG-406": true, "UG-407": true,
	"UG-408": true, "UG-409": true, "UG-410": true, "UG-411": true, "UG-412": true,
	"UG-413": true, "UG-414": true, "UG-415": true, "UG-416": true, "UG-417": true,
	"UG-418": true, "UG-419": true, "UG-C": true, "UG-E": true, "UG-N": true,
	"UG-W": true, "UG-322": true, "UG-323": true, "UG-420": true, "UG-117": true,
	"UG-118": true, "UG-225": true, "UG-120": true, "UG-226": true,
	"UG-121": true, "UG-122": true, "UG-227": true, "UG-421": true,
	"UG-325": true, "UG-228": true, "UG-123": true, "UG-422": true,
	"UG-326": true, "UG-229": true, "UG-124": true, "UG-423": true,
	"UG-230": true, "UG-327": true, "UG-424": true, "UG-328": true,
	"UG-425": true, "UG-426": true, "UG-330": true,
	"UM-67": true, "UM-71": true, "UM-76": true, "UM-79": true,
	"UM-81": true, "UM-84": true, "UM-86": true, "UM-89": true, "UM-95": true,
	"US-AK": true, "US-AL": true, "US-AR": true, "US-AS": true, "US-AZ": true,
	"US-CA": true, "US-CO": true, "US-CT": true, "US-DC": true, "US-DE": true,
	"US-FL": true, "US-GA": true, "US-GU": true, "US-HI": true, "US-IA": true,
	"US-ID": true, "US-IL": true, "US-IN": true, "US-KS": true, "US-KY": true,
	"US-LA": true, "US-MA": true, "US-MD": true, "US-ME": true, "US-MI": true,
	"US-MN": true, "US-MO": true, "US-MP": true, "US-MS": true, "US-MT": true,
	"US-NC": true, "US-ND": true, "US-NE": true, "US-NH": true, "US-NJ": true,
	"US-NM": true, "US-NV": true, "US-NY": true, "US-OH": true, "US-OK": true,
	"US-OR": true, "US-PA": true, "US-PR": true, "US-RI": true, "US-SC": true,
	"US-SD": true, "US-TN": true, "US-TX": true, "US-UM": true, "US-UT": true,
	"US-VA": true, "US-VI": true, "US-VT": true, "US-WA": true, "US-WI": true,
	"US-WV": true, "US-WY": true, "UY-AR": true, "UY-CA": true, "UY-CL": true,
	"UY-CO": true, "UY-DU": true, "UY-FD": true, "UY-FS": true, "UY-LA": true,
	"UY-MA": true, "UY-MO": true, "UY-PA": true, "UY-RN": true, "UY-RO": true,
	"UY-RV": true, "UY-SA": true, "UY-SJ": true, "UY-SO": true, "UY-TA": true,
	"UY-TT": true, "UZ-AN": true, "UZ-BU": true, "UZ-FA": true, "UZ-JI": true,
	"UZ-NG": true, "UZ-NW": true, "UZ-QA": true, "UZ-QR": true, "UZ-SA": true,
	"UZ-SI": true, "UZ-SU": true, "UZ-TK": true, "UZ-TO": true, "UZ-XO": true,
	"VC-01": true, "VC-02": true, "VC-03": true, "VC-04": true, "VC-05": true,
	"VC-06": true, "VE-A": true, "VE-B": true, "VE-C": true, "VE-D": true,
	"VE-E": true, "VE-F": true, "VE-G": true, "VE-H": true, "VE-I": true,
	"VE-J": true, "VE-K": true, "VE-L": true, "VE-M": true, "VE-N": true,
	"VE-O": true, "VE-P": true, "VE-R": true, "VE-S": true, "VE-T": true,
	"VE-U": true, "VE-V": true, "VE-W": true, "VE-X": true, "VE-Y": true,
	"VE-Z": true, "VN-01": true, "VN-02": true, "VN-03": true, "VN-04": true,
	"VN-05": true, "VN-06": true, "VN-07": true, "VN-09": true, "VN-13": true,
	"VN-14": true, "VN-15": true, "VN-18": true, "VN-20": true, "VN-21": true,
	"VN-22": true, "VN-23": true, "VN-24": true, "VN-25": true, "VN-26": true,
	"VN-27": true, "VN-28": true, "VN-29": true, "VN-30": true, "VN-31": true,
	"VN-32": true, "VN-33": true, "VN-34": true, "VN-35": true, "VN-36": true,
	"VN-37": true, "VN-39": true, "VN-40": true, "VN-41": true, "VN-43": true,
	"VN-44": true, "VN-45": true, "VN-46": true, "VN-47": true, "VN-49": true,
	"VN-50": true, "VN-51": true, "VN-52": true, "VN-53": true, "VN-54": true,
	"VN-55": true, "VN-56": true, "VN-57": true, "VN-58": true, "VN-59": true,
	"VN-61": true, "VN-63": true, "VN-66": true, "VN-67": true, "VN-68": true,
	"VN-69": true, "VN-70": true, "VN-71": true, "VN-72": true, "VN-73": true,
	"VN-CT": true, "VN-DN": true, "VN-HN": true, "VN-HP": true, "VN-SG": true,
	"VU-MAP": true, "VU-PAM": true, "VU-SAM": true, "VU-SEE": true, "VU-TAE": true,
	"VU-TOB": true, "WF-SG": true, "WF-UV": true, "WS-AA": true, "WS-AL": true, "WS-AT": true, "WS-FA": true,
	"WS-GE": true, "WS-GI": true, "WS-PA": true, "WS-SA": true, "WS-TU": true,
	"WS-VF": true, "WS-VS": true, "YE-AB": true, "YE-AD": true, "YE-AM": true,
	"YE-BA": true, "YE-DA": true, "YE-DH": true, "YE-HD": true, "YE-HJ": true, "YE-HU": true,
	"YE-IB": true, "YE-JA": true, "YE-LA": true, "YE-MA": true, "YE-MR": true,
	"YE-MU": true, "YE-MW": true, "YE-RA": true, "YE-SA": true, "YE-SD": true, "YE-SH": true,
	"YE-SN": true, "YE-TA": true, "ZA-EC": true, "ZA-FS": true, "ZA-GP": true,
	"ZA-LP": true, "ZA-MP": true, "ZA-NC": true, "ZA-NW": true, "ZA-WC": true,
	"ZA-ZN": true, "ZA-KZN": true, "ZM-01": true, "ZM-02": true, "ZM-03": true, "ZM-04": true,
	"ZM-05": true, "ZM-06": true, "ZM-07": true, "ZM-08": true, "ZM-09": true, "ZM-10": true,
	"ZW-BU": true, "ZW-HA": true, "ZW-MA": true, "ZW-MC": true, "ZW-ME": true,
	"ZW-MI": true, "ZW-MN": true, "ZW-MS": true, "ZW-MV": true, "ZW-MW": true,
}
